# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
ApproxInt module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_approxint.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _ApproxInt
else:
    import _ApproxInt

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _ApproxInt.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _ApproxInt.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ApproxInt.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ApproxInt.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _ApproxInt.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _ApproxInt.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _ApproxInt.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _ApproxInt.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _ApproxInt.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _ApproxInt.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ApproxInt.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _ApproxInt.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _ApproxInt.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ApproxInt.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ApproxInt.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ApproxInt.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _ApproxInt.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _ApproxInt:
_ApproxInt.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _ApproxInt.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TColgp
import OCC.Core.math
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.gp
import OCC.Core.IntSurf
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TopAbs
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d

from enum import IntEnum
from OCC.Core.Exception import *



class ApproxInt_KnotTools(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def BuildKnots(*args) -> "void":
        r"""
        Main function to build optimal knot sequence. at least one set from (thepntsxyz, thepntsu1v1, thepntsu2v2) should exist. @param thepntsxyz - set of 3d points. @param thepntsu1v1 - set of 2d points. @param thepntsu2v2 - set of 2d points. @param thepars - expected parameters assoiated with set. @param theapproxxyz - flag, existence of 3d set. @param theapproxu1v1 - flag existence of first 2d set. @param theapproxu2v2 - flag existence of second 2d set. @param theminnbpnts - minimal number of points per knot interval. @param theknots - output knots sequence.

        Parameters
        ----------
        thePntsXYZ: TColgp_Array1OfPnt
        thePntsU1V1: TColgp_Array1OfPnt2d
        thePntsU2V2: TColgp_Array1OfPnt2d
        thePars: math_Vector
        theApproxXYZ: bool
        theApproxU1V1: bool
        theApproxU2V2: bool
        theMinNbPnts: int
        theKnots: NCollection_Vector<int>

        Returns
        -------
        None

        """
        return _ApproxInt.ApproxInt_KnotTools_BuildKnots(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _ApproxInt.ApproxInt_KnotTools_swiginit(self, _ApproxInt.new_ApproxInt_KnotTools())
    __swig_destroy__ = _ApproxInt.delete_ApproxInt_KnotTools

# Register ApproxInt_KnotTools in _ApproxInt:
_ApproxInt.ApproxInt_KnotTools_swigregister(ApproxInt_KnotTools)

def ApproxInt_KnotTools_BuildKnots(*args) -> "void":
    r"""
    Main function to build optimal knot sequence. at least one set from (thepntsxyz, thepntsu1v1, thepntsu2v2) should exist. @param thepntsxyz - set of 3d points. @param thepntsu1v1 - set of 2d points. @param thepntsu2v2 - set of 2d points. @param thepars - expected parameters assoiated with set. @param theapproxxyz - flag, existence of 3d set. @param theapproxu1v1 - flag existence of first 2d set. @param theapproxu2v2 - flag existence of second 2d set. @param theminnbpnts - minimal number of points per knot interval. @param theknots - output knots sequence.

    Parameters
    ----------
    thePntsXYZ: TColgp_Array1OfPnt
    thePntsU1V1: TColgp_Array1OfPnt2d
    thePntsU2V2: TColgp_Array1OfPnt2d
    thePars: math_Vector
    theApproxXYZ: bool
    theApproxU1V1: bool
    theApproxU2V2: bool
    theMinNbPnts: int
    theKnots: NCollection_Vector<int>

    Returns
    -------
    None

    """
    return _ApproxInt.ApproxInt_KnotTools_BuildKnots(*args)

class ApproxInt_SvSurfaces(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Compute(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if tg,tguv1 tguv2 can be computed.

        Parameters
        ----------
        Pt: gp_Pnt
        Tg: gp_Vec
        Tguv1: gp_Vec2d
        Tguv2: gp_Vec2d

        Returns
        -------
        u1: float
        v1: float
        u2: float
        v2: float

        """
        return _ApproxInt.ApproxInt_SvSurfaces_Compute(self, *args)

    def Pnt(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        u1: float
        v1: float
        u2: float
        v2: float
        P: gp_Pnt

        Returns
        -------
        None

        """
        return _ApproxInt.ApproxInt_SvSurfaces_Pnt(self, *args)

    def SeekPoint(self, *args) -> "Standard_Boolean":
        r"""
        Computes point on curve and parameters on the surfaces.

        Parameters
        ----------
        u1: float
        v1: float
        u2: float
        v2: float
        Point: IntSurf_PntOn2S

        Returns
        -------
        bool

        """
        return _ApproxInt.ApproxInt_SvSurfaces_SeekPoint(self, *args)

    def Tangency(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        u1: float
        v1: float
        u2: float
        v2: float
        Tg: gp_Vec

        Returns
        -------
        bool

        """
        return _ApproxInt.ApproxInt_SvSurfaces_Tangency(self, *args)

    def TangencyOnSurf1(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        u1: float
        v1: float
        u2: float
        v2: float
        Tg: gp_Vec2d

        Returns
        -------
        bool

        """
        return _ApproxInt.ApproxInt_SvSurfaces_TangencyOnSurf1(self, *args)

    def TangencyOnSurf2(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        u1: float
        v1: float
        u2: float
        v2: float
        Tg: gp_Vec2d

        Returns
        -------
        bool

        """
        return _ApproxInt.ApproxInt_SvSurfaces_TangencyOnSurf2(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ApproxInt.delete_ApproxInt_SvSurfaces

# Register ApproxInt_SvSurfaces in _ApproxInt:
_ApproxInt.ApproxInt_SvSurfaces_swigregister(ApproxInt_SvSurfaces)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColgp import *
from OCC.Core.gp import *
from OCC.Core.math import *
from OCC.Core.TColStd import *


class CSLib_NormalStatus(IntEnum):
	CSLib_Singular: int = ...
	CSLib_Defined: int = ...
	CSLib_InfinityOfSolutions: int = ...
	CSLib_D1NuIsNull: int = ...
	CSLib_D1NvIsNull: int = ...
	CSLib_D1NIsNull: int = ...
	CSLib_D1NuNvRatioIsNull: int = ...
	CSLib_D1NvNuRatioIsNull: int = ...
	CSLib_D1NuIsParallelD1Nv: int = ...
CSLib_Singular = CSLib_NormalStatus.CSLib_Singular
CSLib_Defined = CSLib_NormalStatus.CSLib_Defined
CSLib_InfinityOfSolutions = CSLib_NormalStatus.CSLib_InfinityOfSolutions
CSLib_D1NuIsNull = CSLib_NormalStatus.CSLib_D1NuIsNull
CSLib_D1NvIsNull = CSLib_NormalStatus.CSLib_D1NvIsNull
CSLib_D1NIsNull = CSLib_NormalStatus.CSLib_D1NIsNull
CSLib_D1NuNvRatioIsNull = CSLib_NormalStatus.CSLib_D1NuNvRatioIsNull
CSLib_D1NvNuRatioIsNull = CSLib_NormalStatus.CSLib_D1NvNuRatioIsNull
CSLib_D1NuIsParallelD1Nv = CSLib_NormalStatus.CSLib_D1NuIsParallelD1Nv

class CSLib_DerivativeStatus(IntEnum):
	CSLib_Done: int = ...
	CSLib_D1uIsNull: int = ...
	CSLib_D1vIsNull: int = ...
	CSLib_D1IsNull: int = ...
	CSLib_D1uD1vRatioIsNull: int = ...
	CSLib_D1vD1uRatioIsNull: int = ...
	CSLib_D1uIsParallelD1v: int = ...
CSLib_Done = CSLib_DerivativeStatus.CSLib_Done
CSLib_D1uIsNull = CSLib_DerivativeStatus.CSLib_D1uIsNull
CSLib_D1vIsNull = CSLib_DerivativeStatus.CSLib_D1vIsNull
CSLib_D1IsNull = CSLib_DerivativeStatus.CSLib_D1IsNull
CSLib_D1uD1vRatioIsNull = CSLib_DerivativeStatus.CSLib_D1uD1vRatioIsNull
CSLib_D1vD1uRatioIsNull = CSLib_DerivativeStatus.CSLib_D1vD1uRatioIsNull
CSLib_D1uIsParallelD1v = CSLib_DerivativeStatus.CSLib_D1uIsParallelD1v

class cslib:
	@overload
	@staticmethod
	def DNNUV(Nu: int, Nv: int, DerSurf: TColgp_Array2OfVec) -> gp_Vec: ...
	@overload
	@staticmethod
	def DNNUV(Nu: int, Nv: int, DerSurf1: TColgp_Array2OfVec, DerSurf2: TColgp_Array2OfVec) -> gp_Vec: ...
	@staticmethod
	def DNNormal(Nu: int, Nv: int, DerNUV: TColgp_Array2OfVec, Iduref: Optional[int] = 0, Idvref: Optional[int] = 0) -> gp_Vec: ...
	@overload
	@staticmethod
	def Normal(D1U: gp_Vec, D1V: gp_Vec, SinTol: float, theStatus: CSLib_DerivativeStatus, Normal: gp_Dir) -> None: ...
	@overload
	@staticmethod
	def Normal(D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, SinTol: float, theStatus: CSLib_NormalStatus, Normal: gp_Dir) -> bool: ...
	@overload
	@staticmethod
	def Normal(D1U: gp_Vec, D1V: gp_Vec, MagTol: float, theStatus: CSLib_NormalStatus, Normal: gp_Dir) -> None: ...
	@overload
	@staticmethod
	def Normal(MaxOrder: int, DerNUV: TColgp_Array2OfVec, MagTol: float, U: float, V: float, Umin: float, Umax: float, Vmin: float, Vmax: float, theStatus: CSLib_NormalStatus, Normal: gp_Dir) -> Tuple[int, int]: ...

class CSLib_Class2d:
	@overload
	def __init__(self, thePnts2d: TColgp_Array1OfPnt2d, theTolU: float, theTolV: float, theUMin: float, theVMin: float, theUMax: float, theVMax: float) -> None: ...
	@overload
	def __init__(self, thePnts2d: TColgp_SequenceOfPnt2d, theTolU: float, theTolV: float, theUMin: float, theVMin: float, theUMax: float, theVMax: float) -> None: ...
	def InternalSiDans(self, X: float, Y: float) -> int: ...
	def InternalSiDansOuOn(self, X: float, Y: float) -> int: ...
	def SiDans(self, P: gp_Pnt2d) -> int: ...
	def SiDans_OnMode(self, P: gp_Pnt2d, Tol: float) -> int: ...

class CSLib_NormalPolyDef(math_FunctionWithDerivative):
	def __init__(self, k0: int, li: TColStd_Array1OfReal) -> None: ...
	def Derivative(self, X: float) -> Tuple[bool, float]: ...
	def Value(self, X: float) -> Tuple[bool, float]: ...
	def Values(self, X: float) -> Tuple[bool, float, float]: ...

# harray1 classes
# harray2 classes
# hsequence classes

cslib_DNNUV = cslib.DNNUV
cslib_DNNUV = cslib.DNNUV
cslib_DNNormal = cslib.DNNormal
cslib_Normal = cslib.Normal
cslib_Normal = cslib.Normal
cslib_Normal = cslib.Normal
cslib_Normal = cslib.Normal



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColStd import *
from OCC.Core.Bnd import *
from OCC.Core.IntTools import *
from OCC.Core.TopoDS import *
from OCC.Core.TopTools import *
from OCC.Core.TopAbs import *
from OCC.Core.gp import *

#the following typedef cannot be wrapped as is
BOPDS_DataMapIteratorOfDataMapOfPaveBlockCommonBlock = NewType('BOPDS_DataMapIteratorOfDataMapOfPaveBlockCommonBlock', Any)
#the following typedef cannot be wrapped as is
BOPDS_DataMapIteratorOfDataMapOfPaveBlockListOfInteger = NewType('BOPDS_DataMapIteratorOfDataMapOfPaveBlockListOfInteger', Any)
#the following typedef cannot be wrapped as is
BOPDS_DataMapIteratorOfDataMapOfPaveBlockListOfPaveBlock = NewType('BOPDS_DataMapIteratorOfDataMapOfPaveBlockListOfPaveBlock', Any)
#the following typedef cannot be wrapped as is
BOPDS_DataMapIteratorOfDataMapOfShapeCoupleOfPaveBlocks = NewType('BOPDS_DataMapIteratorOfDataMapOfShapeCoupleOfPaveBlocks', Any)
#the following typedef cannot be wrapped as is
BOPDS_IndexedDataMapOfPaveBlockListOfInteger = NewType('BOPDS_IndexedDataMapOfPaveBlockListOfInteger', Any)
#the following typedef cannot be wrapped as is
BOPDS_IndexedDataMapOfPaveBlockListOfPaveBlock = NewType('BOPDS_IndexedDataMapOfPaveBlockListOfPaveBlock', Any)
#the following typedef cannot be wrapped as is
BOPDS_IndexedDataMapOfShapeCoupleOfPaveBlocks = NewType('BOPDS_IndexedDataMapOfShapeCoupleOfPaveBlocks', Any)
#the following typedef cannot be wrapped as is
BOPDS_IndexedMapOfPaveBlock = NewType('BOPDS_IndexedMapOfPaveBlock', Any)
#the following typedef cannot be wrapped as is
BOPDS_ListIteratorOfListOfPave = NewType('BOPDS_ListIteratorOfListOfPave', Any)
#the following typedef cannot be wrapped as is
BOPDS_ListIteratorOfListOfPaveBlock = NewType('BOPDS_ListIteratorOfListOfPaveBlock', Any)
#the following typedef cannot be wrapped as is
BOPDS_MapIteratorOfMapOfCommonBlock = NewType('BOPDS_MapIteratorOfMapOfCommonBlock', Any)
#the following typedef cannot be wrapped as is
BOPDS_MapIteratorOfMapOfPair = NewType('BOPDS_MapIteratorOfMapOfPair', Any)
#the following typedef cannot be wrapped as is
BOPDS_MapIteratorOfMapOfPave = NewType('BOPDS_MapIteratorOfMapOfPave', Any)
#the following typedef cannot be wrapped as is
BOPDS_MapIteratorOfMapOfPaveBlock = NewType('BOPDS_MapIteratorOfMapOfPaveBlock', Any)
#the following typedef cannot be wrapped as is
BOPDS_MapOfCommonBlock = NewType('BOPDS_MapOfCommonBlock', Any)
#the following typedef cannot be wrapped as is
BOPDS_MapOfPair = NewType('BOPDS_MapOfPair', Any)
#the following typedef cannot be wrapped as is
BOPDS_MapOfPave = NewType('BOPDS_MapOfPave', Any)
#the following typedef cannot be wrapped as is
BOPDS_MapOfPaveBlock = NewType('BOPDS_MapOfPaveBlock', Any)
BOPDS_PDS = NewType('BOPDS_PDS', BOPDS_DS)
BOPDS_PIterator = NewType('BOPDS_PIterator', BOPDS_Iterator)
BOPDS_PIteratorSI = NewType('BOPDS_PIteratorSI', BOPDS_IteratorSI)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfCurve = NewType('BOPDS_VectorOfCurve', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfFaceInfo = NewType('BOPDS_VectorOfFaceInfo', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfIndexRange = NewType('BOPDS_VectorOfIndexRange', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfInterfEE = NewType('BOPDS_VectorOfInterfEE', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfInterfEF = NewType('BOPDS_VectorOfInterfEF', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfInterfEZ = NewType('BOPDS_VectorOfInterfEZ', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfInterfFF = NewType('BOPDS_VectorOfInterfFF', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfInterfFZ = NewType('BOPDS_VectorOfInterfFZ', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfInterfVE = NewType('BOPDS_VectorOfInterfVE', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfInterfVF = NewType('BOPDS_VectorOfInterfVF', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfInterfVV = NewType('BOPDS_VectorOfInterfVV', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfInterfVZ = NewType('BOPDS_VectorOfInterfVZ', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfInterfZZ = NewType('BOPDS_VectorOfInterfZZ', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfListOfPaveBlock = NewType('BOPDS_VectorOfListOfPaveBlock', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfPair = NewType('BOPDS_VectorOfPair', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfPoint = NewType('BOPDS_VectorOfPoint', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfShapeInfo = NewType('BOPDS_VectorOfShapeInfo', Any)
#the following typedef cannot be wrapped as is
BOPDS_VectorOfVectorOfPair = NewType('BOPDS_VectorOfVectorOfPair', Any)

class BOPDS_ListOfPave:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> BOPDS_Pave: ...
    def Last(self) -> BOPDS_Pave: ...
    def Append(self, theItem: BOPDS_Pave) -> BOPDS_Pave: ...
    def Prepend(self, theItem: BOPDS_Pave) -> BOPDS_Pave: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> BOPDS_Pave: ...
    def SetValue(self, theIndex: int, theValue: BOPDS_Pave) -> None: ...

class BOPDS_ListOfPaveBlock:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class BOPDS_VectorOfPave:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> BOPDS_Pave: ...
    def __setitem__(self, index: int, value: BOPDS_Pave) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[BOPDS_Pave]: ...
    def next(self) -> BOPDS_Pave: ...
    __next__ = next
    def Init(self, theValue: BOPDS_Pave) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> BOPDS_Pave: ...
    def Last(self) -> BOPDS_Pave: ...
    def Value(self, theIndex: int) -> BOPDS_Pave: ...
    def SetValue(self, theIndex: int, theValue: BOPDS_Pave) -> None: ...

class BOPDS_CommonBlock(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def AddFace(self, aF: int) -> None: ...
	def AddPaveBlock(self, aPB: BOPDS_PaveBlock) -> None: ...
	def AppendFaces(self, aLF: TColStd_ListOfInteger) -> None: ...
	@overload
	def Contains(self, thePB: BOPDS_PaveBlock) -> bool: ...
	@overload
	def Contains(self, theF: int) -> bool: ...
	def Dump(self) -> None: ...
	def Edge(self) -> int: ...
	def Faces(self) -> TColStd_ListOfInteger: ...
	def IsPaveBlockOnEdge(self, theIndex: int) -> bool: ...
	def IsPaveBlockOnFace(self, theIndex: int) -> bool: ...
	def PaveBlock1(self) -> BOPDS_PaveBlock: ...
	def PaveBlockOnEdge(self, theIndex: int) -> BOPDS_PaveBlock: ...
	def PaveBlocks(self) -> BOPDS_ListOfPaveBlock: ...
	def SetEdge(self, theEdge: int) -> None: ...
	def SetFaces(self, aLF: TColStd_ListOfInteger) -> None: ...
	def SetPaveBlocks(self, aLPB: BOPDS_ListOfPaveBlock) -> None: ...
	def SetRealPaveBlock(self, thePB: BOPDS_PaveBlock) -> None: ...
	def SetTolerance(self, theTol: float) -> None: ...
	def Tolerance(self) -> float: ...

class BOPDS_CoupleOfPaveBlocks:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, thePB1: BOPDS_PaveBlock, thePB2: BOPDS_PaveBlock) -> None: ...
	def Index(self) -> int: ...
	def IndexInterf(self) -> int: ...
	def PaveBlock1(self) -> BOPDS_PaveBlock: ...
	def PaveBlock2(self) -> BOPDS_PaveBlock: ...
	def PaveBlocks(self, thePB1: BOPDS_PaveBlock, thePB2: BOPDS_PaveBlock) -> None: ...
	def SetIndex(self, theIndex: int) -> None: ...
	def SetIndexInterf(self, theIndex: int) -> None: ...
	def SetPaveBlock1(self, thePB: BOPDS_PaveBlock) -> None: ...
	def SetPaveBlock2(self, thePB: BOPDS_PaveBlock) -> None: ...
	def SetPaveBlocks(self, thePB1: BOPDS_PaveBlock, thePB2: BOPDS_PaveBlock) -> None: ...
	def SetTolerance(self, theTol: float) -> None: ...
	def Tolerance(self) -> float: ...

class BOPDS_Curve:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def Box(self) -> Bnd_Box: ...
	def ChangeBox(self) -> Bnd_Box: ...
	def ChangePaveBlock1(self) -> BOPDS_PaveBlock: ...
	def ChangePaveBlocks(self) -> BOPDS_ListOfPaveBlock: ...
	def ChangeTechnoVertices(self) -> TColStd_ListOfInteger: ...
	def Curve(self) -> IntTools_Curve: ...
	def HasEdge(self) -> bool: ...
	def InitPaveBlock1(self) -> None: ...
	def PaveBlocks(self) -> BOPDS_ListOfPaveBlock: ...
	def SetBox(self, theBox: Bnd_Box) -> None: ...
	def SetCurve(self, theC: IntTools_Curve) -> None: ...
	def SetPaveBlocks(self, theLPB: BOPDS_ListOfPaveBlock) -> None: ...
	def SetTolerance(self, theTol: float) -> None: ...
	def TangentialTolerance(self) -> float: ...
	def TechnoVertices(self) -> TColStd_ListOfInteger: ...
	def Tolerance(self) -> float: ...

class BOPDS_DS:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def AddInterf(self, theI1: int, theI2: int) -> bool: ...
	def AddShapeSD(self, theIndex: int, theIndexSD: int) -> None: ...
	def Allocator(self) -> NCollection_BaseAllocator: ...
	def AloneVertices(self, theF: int, theLI: TColStd_ListOfInteger) -> None: ...
	@overload
	def Append(self, theSI: BOPDS_ShapeInfo) -> int: ...
	@overload
	def Append(self, theS: TopoDS_Shape) -> int: ...
	def Arguments(self) -> TopTools_ListOfShape: ...
	def BuildBndBoxSolid(self, theIndex: int, theBox: Bnd_Box, theCheckInverted: Optional[bool] = True) -> None: ...
	def ChangeFaceInfo(self, theIndex: int) -> BOPDS_FaceInfo: ...
	def ChangePaveBlocks(self, theIndex: int) -> BOPDS_ListOfPaveBlock: ...
	def ChangePaveBlocksPool(self) -> BOPDS_VectorOfListOfPaveBlock: ...
	def ChangeShapeInfo(self, theIndex: int) -> BOPDS_ShapeInfo: ...
	def Clear(self) -> None: ...
	def CommonBlock(self, thePB: BOPDS_PaveBlock) -> BOPDS_CommonBlock: ...
	def Dump(self) -> None: ...
	def FaceInfo(self, theIndex: int) -> BOPDS_FaceInfo: ...
	def FaceInfoIn(self, theIndex: int, theMPB: BOPDS_IndexedMapOfPaveBlock, theMVP: TColStd_MapOfInteger) -> None: ...
	def FaceInfoOn(self, theIndex: int, theMPB: BOPDS_IndexedMapOfPaveBlock, theMVP: TColStd_MapOfInteger) -> None: ...
	def FaceInfoPool(self) -> BOPDS_VectorOfFaceInfo: ...
	def HasFaceInfo(self, theIndex: int) -> bool: ...
	@overload
	def HasInterf(self, theI: int) -> bool: ...
	@overload
	def HasInterf(self, theI1: int, theI2: int) -> bool: ...
	def HasInterfShapeSubShapes(self, theI1: int, theI2: int, theFlag: Optional[bool] = True) -> bool: ...
	def HasInterfSubShapes(self, theI1: int, theI2: int) -> bool: ...
	def HasPaveBlocks(self, theIndex: int) -> bool: ...
	def HasShapeSD(self, theIndex: int) -> Tuple[bool, int]: ...
	def Index(self, theS: TopoDS_Shape) -> int: ...
	def Init(self, theFuzz: Optional[float] = precision_Confusion()) -> None: ...
	def InitPaveBlocksForVertex(self, theNV: int) -> None: ...
	def InterfEE(self) -> BOPDS_VectorOfInterfEE: ...
	def InterfEF(self) -> BOPDS_VectorOfInterfEF: ...
	def InterfEZ(self) -> BOPDS_VectorOfInterfEZ: ...
	def InterfFF(self) -> BOPDS_VectorOfInterfFF: ...
	def InterfFZ(self) -> BOPDS_VectorOfInterfFZ: ...
	def InterfVE(self) -> BOPDS_VectorOfInterfVE: ...
	def InterfVF(self) -> BOPDS_VectorOfInterfVF: ...
	def InterfVV(self) -> BOPDS_VectorOfInterfVV: ...
	def InterfVZ(self) -> BOPDS_VectorOfInterfVZ: ...
	def InterfZZ(self) -> BOPDS_VectorOfInterfZZ: ...
	def Interferences(self) -> BOPDS_MapOfPair: ...
	def IsCommonBlock(self, thePB: BOPDS_PaveBlock) -> bool: ...
	def IsCommonBlockOnEdge(self, thePB: BOPDS_PaveBlock) -> bool: ...
	def IsNewShape(self, theIndex: int) -> bool: ...
	def IsSubShape(self, theI1: int, theI2: int) -> bool: ...
	def IsValidShrunkData(self, thePB: BOPDS_PaveBlock) -> bool: ...
	@staticmethod
	def NbInterfTypes() -> int: ...
	def NbRanges(self) -> int: ...
	def NbShapes(self) -> int: ...
	def NbSourceShapes(self) -> int: ...
	def PaveBlocks(self, theIndex: int) -> BOPDS_ListOfPaveBlock: ...
	def PaveBlocksPool(self) -> BOPDS_VectorOfListOfPaveBlock: ...
	def Paves(self, theIndex: int, theLP: BOPDS_ListOfPave) -> None: ...
	def Range(self, theIndex: int) -> BOPDS_IndexRange: ...
	def Rank(self, theIndex: int) -> int: ...
	def RealPaveBlock(self, thePB: BOPDS_PaveBlock) -> BOPDS_PaveBlock: ...
	def RefineFaceInfoIn(self) -> None: ...
	def RefineFaceInfoOn(self) -> None: ...
	def ReleasePaveBlocks(self) -> None: ...
	def SetArguments(self, theLS: TopTools_ListOfShape) -> None: ...
	def SetCommonBlock(self, thePB: BOPDS_PaveBlock, theCB: BOPDS_CommonBlock) -> None: ...
	def Shape(self, theIndex: int) -> TopoDS_Shape: ...
	def ShapeInfo(self, theIndex: int) -> BOPDS_ShapeInfo: ...
	def ShapesSD(self) -> TColStd_DataMapOfIntegerInteger: ...
	def SharedEdges(self, theF1: int, theF2: int, theLI: TColStd_ListOfInteger, theAllocator: NCollection_BaseAllocator) -> None: ...
	def SubShapesOnIn(self, theNF1: int, theNF2: int, theMVOnIn: TColStd_MapOfInteger, theMVCommon: TColStd_MapOfInteger, thePBOnIn: BOPDS_IndexedMapOfPaveBlock, theCommonPB: BOPDS_MapOfPaveBlock) -> None: ...
	def UpdateCommonBlock(self, theCB: BOPDS_CommonBlock, theFuzz: float) -> None: ...
	def UpdateCommonBlockWithSDVertices(self, theCB: BOPDS_CommonBlock) -> None: ...
	@overload
	def UpdateFaceInfoIn(self, theIndex: int) -> None: ...
	@overload
	def UpdateFaceInfoIn(self, theFaces: TColStd_MapOfInteger) -> None: ...
	@overload
	def UpdateFaceInfoOn(self, theIndex: int) -> None: ...
	@overload
	def UpdateFaceInfoOn(self, theFaces: TColStd_MapOfInteger) -> None: ...
	def UpdatePaveBlock(self, thePB: BOPDS_PaveBlock) -> None: ...
	def UpdatePaveBlockWithSDVertices(self, thePB: BOPDS_PaveBlock) -> None: ...
	def UpdatePaveBlocks(self) -> None: ...
	def UpdatePaveBlocksWithSDVertices(self) -> None: ...

class BOPDS_FaceInfo:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def ChangePaveBlocksIn(self) -> BOPDS_IndexedMapOfPaveBlock: ...
	def ChangePaveBlocksOn(self) -> BOPDS_IndexedMapOfPaveBlock: ...
	def ChangePaveBlocksSc(self) -> BOPDS_IndexedMapOfPaveBlock: ...
	def ChangeVerticesIn(self) -> TColStd_MapOfInteger: ...
	def ChangeVerticesOn(self) -> TColStd_MapOfInteger: ...
	def ChangeVerticesSc(self) -> TColStd_MapOfInteger: ...
	def Clear(self) -> None: ...
	def Index(self) -> int: ...
	def PaveBlocksIn(self) -> BOPDS_IndexedMapOfPaveBlock: ...
	def PaveBlocksOn(self) -> BOPDS_IndexedMapOfPaveBlock: ...
	def PaveBlocksSc(self) -> BOPDS_IndexedMapOfPaveBlock: ...
	def SetIndex(self, theI: int) -> None: ...
	def VerticesIn(self) -> TColStd_MapOfInteger: ...
	def VerticesOn(self) -> TColStd_MapOfInteger: ...
	def VerticesSc(self) -> TColStd_MapOfInteger: ...

class BOPDS_IndexRange:
	def __init__(self) -> None: ...
	def Contains(self, theIndex: int) -> bool: ...
	def Dump(self) -> None: ...
	def First(self) -> int: ...
	def Indices(self) -> Tuple[int, int]: ...
	def Last(self) -> int: ...
	def SetFirst(self, theI1: int) -> None: ...
	def SetIndices(self, theI1: int, theI2: int) -> None: ...
	def SetLast(self, theI2: int) -> None: ...

class BOPDS_Iterator:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def BlockLength(self) -> int: ...
	def DS(self) -> BOPDS_DS: ...
	def ExpectedLength(self) -> int: ...
	def Initialize(self, theType1: TopAbs_ShapeEnum, theType2: TopAbs_ShapeEnum) -> None: ...
	def IntersectExt(self, theIndicies: TColStd_MapOfInteger) -> None: ...
	def More(self) -> bool: ...
	@staticmethod
	def NbExtInterfs() -> int: ...
	def Next(self) -> None: ...
	def Prepare(self, theCtx: Optional[IntTools_Context] = IntTools_Context(), theCheckOBB: Optional[bool] = False, theFuzzyValue: Optional[float] = precision_Confusion()) -> None: ...
	def RunParallel(self) -> bool: ...
	def SetDS(self, pDS: BOPDS_PDS) -> None: ...
	def SetRunParallel(self, theFlag: bool) -> None: ...
	def Value(self) -> Tuple[int, int]: ...

class BOPDS_Pair:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theIndex1: int, theIndex2: int) -> None: ...
	def HashCode(self, theUpperBound: int) -> int: ...
	def Indices(self) -> Tuple[int, int]: ...
	def IsEqual(self, theOther: BOPDS_Pair) -> bool: ...
	def SetIndices(self, theIndex1: int, theIndex2: int) -> None: ...

class BOPDS_PairMapHasher:
	@staticmethod
	def HashCode(thePair: BOPDS_Pair, theUpperBound: int) -> int: ...
	@staticmethod
	def IsEqual(thePair1: BOPDS_Pair, thePair2: BOPDS_Pair) -> bool: ...

class BOPDS_Pave:
	def __init__(self) -> None: ...
	def Contents(self) -> Tuple[int, float]: ...
	def Dump(self) -> None: ...
	def Index(self) -> int: ...
	def IsEqual(self, theOther: BOPDS_Pave) -> bool: ...
	def IsLess(self, theOther: BOPDS_Pave) -> bool: ...
	def Parameter(self) -> float: ...
	def SetIndex(self, theIndex: int) -> None: ...
	def SetParameter(self, theParameter: float) -> None: ...

class BOPDS_PaveBlock(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def AppendExtPave(self, thePave: BOPDS_Pave) -> None: ...
	def AppendExtPave1(self, thePave: BOPDS_Pave) -> None: ...
	def ChangeExtPaves(self) -> BOPDS_ListOfPave: ...
	def ContainsParameter(self, thePrm: float, theTol: float) -> Tuple[bool, int]: ...
	def Dump(self) -> None: ...
	def Edge(self) -> int: ...
	def ExtPaves(self) -> BOPDS_ListOfPave: ...
	@overload
	def HasEdge(self) -> bool: ...
	@overload
	def HasEdge(self) -> Tuple[bool, int]: ...
	def HasSameBounds(self, theOther: BOPDS_PaveBlock) -> bool: ...
	def HasShrunkData(self) -> bool: ...
	def Indices(self) -> Tuple[int, int]: ...
	def IsSplitEdge(self) -> bool: ...
	def IsSplittable(self) -> bool: ...
	def IsToUpdate(self) -> bool: ...
	def OriginalEdge(self) -> int: ...
	def Pave1(self) -> BOPDS_Pave: ...
	def Pave2(self) -> BOPDS_Pave: ...
	def Range(self) -> Tuple[float, float]: ...
	def RemoveExtPave(self, theVertNum: int) -> None: ...
	def SetEdge(self, theEdge: int) -> None: ...
	def SetOriginalEdge(self, theEdge: int) -> None: ...
	def SetPave1(self, thePave: BOPDS_Pave) -> None: ...
	def SetPave2(self, thePave: BOPDS_Pave) -> None: ...
	def SetShrunkData(self, theTS1: float, theTS2: float, theBox: Bnd_Box, theIsSplittable: bool) -> None: ...
	def ShrunkData(self, theBox: Bnd_Box) -> Tuple[float, float, bool]: ...
	def Update(self, theLPB: BOPDS_ListOfPaveBlock, theFlag: Optional[bool] = True) -> None: ...

class BOPDS_PaveMapHasher:
	@staticmethod
	def HashCode(thePave: BOPDS_Pave, theUpperBound: int) -> int: ...
	@staticmethod
	def IsEqual(aPave1: BOPDS_Pave, aPave2: BOPDS_Pave) -> bool: ...

class BOPDS_Point:
	def __init__(self) -> None: ...
	def Index(self) -> int: ...
	def Pnt(self) -> gp_Pnt: ...
	def Pnt2D1(self) -> gp_Pnt2d: ...
	def Pnt2D2(self) -> gp_Pnt2d: ...
	def SetIndex(self, theIndex: int) -> None: ...
	def SetPnt(self, thePnt: gp_Pnt) -> None: ...
	def SetPnt2D1(self, thePnt: gp_Pnt2d) -> None: ...
	def SetPnt2D2(self, thePnt: gp_Pnt2d) -> None: ...

class BOPDS_ShapeInfo:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def Box(self) -> Bnd_Box: ...
	def ChangeBox(self) -> Bnd_Box: ...
	def ChangeSubShapes(self) -> TColStd_ListOfInteger: ...
	def Dump(self) -> None: ...
	def Flag(self) -> int: ...
	def HasBRep(self) -> bool: ...
	@overload
	def HasFlag(self) -> bool: ...
	@overload
	def HasFlag(self) -> Tuple[bool, int]: ...
	def HasReference(self) -> bool: ...
	def HasSubShape(self, theI: int) -> bool: ...
	def IsInterfering(self) -> bool: ...
	def Reference(self) -> int: ...
	def SetBox(self, theBox: Bnd_Box) -> None: ...
	def SetFlag(self, theI: int) -> None: ...
	def SetReference(self, theI: int) -> None: ...
	def SetShape(self, theS: TopoDS_Shape) -> None: ...
	def SetShapeType(self, theType: TopAbs_ShapeEnum) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...
	def ShapeType(self) -> TopAbs_ShapeEnum: ...
	def SubShapes(self) -> TColStd_ListOfInteger: ...

class BOPDS_SubIterator:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def DS(self) -> BOPDS_DS: ...
	def ExpectedLength(self) -> int: ...
	def Initialize(self) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Prepare(self) -> None: ...
	def SetDS(self, pDS: BOPDS_PDS) -> None: ...
	def SetSubSet1(self, theLI: TColStd_ListOfInteger) -> None: ...
	def SetSubSet2(self, theLI: TColStd_ListOfInteger) -> None: ...
	def SubSet1(self) -> TColStd_ListOfInteger: ...
	def SubSet2(self) -> TColStd_ListOfInteger: ...
	def Value(self) -> Tuple[int, int]: ...

class BOPDS_Tools:
	@staticmethod
	def HasBRep(theT: TopAbs_ShapeEnum) -> bool: ...
	@staticmethod
	def IsInterfering(theT: TopAbs_ShapeEnum) -> bool: ...
	@overload
	@staticmethod
	def TypeToInteger(theT1: TopAbs_ShapeEnum, theT2: TopAbs_ShapeEnum) -> int: ...
	@overload
	@staticmethod
	def TypeToInteger(theT: TopAbs_ShapeEnum) -> int: ...

class BOPDS_InterfEE(BOPDS_Interf):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def CommonPart(self) -> IntTools_CommonPrt: ...
	def SetCommonPart(self, theCP: IntTools_CommonPrt) -> None: ...

class BOPDS_InterfEF(BOPDS_Interf):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def CommonPart(self) -> IntTools_CommonPrt: ...
	def SetCommonPart(self, theCP: IntTools_CommonPrt) -> None: ...

class BOPDS_InterfEZ(BOPDS_Interf):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...

class BOPDS_InterfFF(BOPDS_Interf):
	def __init__(self) -> None: ...
	def ChangeCurves(self) -> BOPDS_VectorOfCurve: ...
	def ChangePoints(self) -> BOPDS_VectorOfPoint: ...
	def Curves(self) -> BOPDS_VectorOfCurve: ...
	def Init(self, theNbCurves: int, theNbPoints: int) -> None: ...
	def Points(self) -> BOPDS_VectorOfPoint: ...
	def SetTangentFaces(self, theFlag: bool) -> None: ...
	def TangentFaces(self) -> bool: ...

class BOPDS_InterfFZ(BOPDS_Interf):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...

class BOPDS_InterfVE(BOPDS_Interf):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def Parameter(self) -> float: ...
	def SetParameter(self, theT: float) -> None: ...

class BOPDS_InterfVF(BOPDS_Interf):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def SetUV(self, theU: float, theV: float) -> None: ...
	def UV(self) -> Tuple[float, float]: ...

class BOPDS_InterfVV(BOPDS_Interf):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...

class BOPDS_InterfVZ(BOPDS_Interf):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...

class BOPDS_InterfZZ(BOPDS_Interf):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...

class BOPDS_IteratorSI(BOPDS_Iterator):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def UpdateByLevelOfCheck(self, theLevel: int) -> None: ...

#classnotwrapped
class BOPDS_Interf: ...

# harray1 classes
# harray2 classes
# hsequence classes

BOPDS_DS_NbInterfTypes = BOPDS_DS.NbInterfTypes
BOPDS_Iterator_NbExtInterfs = BOPDS_Iterator.NbExtInterfs
BOPDS_PairMapHasher_HashCode = BOPDS_PairMapHasher.HashCode
BOPDS_PairMapHasher_IsEqual = BOPDS_PairMapHasher.IsEqual
BOPDS_PaveMapHasher_HashCode = BOPDS_PaveMapHasher.HashCode
BOPDS_PaveMapHasher_IsEqual = BOPDS_PaveMapHasher.IsEqual
BOPDS_Tools_HasBRep = BOPDS_Tools.HasBRep
BOPDS_Tools_IsInterfering = BOPDS_Tools.IsInterfering
BOPDS_Tools_TypeToInteger = BOPDS_Tools.TypeToInteger
BOPDS_Tools_TypeToInteger = BOPDS_Tools.TypeToInteger



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Interface import *
from OCC.Core.TColStd import *
from OCC.Core.TCollection import *
from OCC.Core.MoniTool import *


class IFSelect_SequenceOfAppliedModifiers:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class IFSelect_SequenceOfGeneralModifier:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class IFSelect_SequenceOfInterfaceModel:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class IFSelect_TSeqOfDispatch:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class IFSelect_TSeqOfSelection:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class IFSelect_PrintFail(IntEnum):
	IFSelect_FailOnly: int = ...
	IFSelect_FailAndWarn: int = ...
IFSelect_FailOnly = IFSelect_PrintFail.IFSelect_FailOnly
IFSelect_FailAndWarn = IFSelect_PrintFail.IFSelect_FailAndWarn

class IFSelect_RemainMode(IntEnum):
	IFSelect_RemainForget: int = ...
	IFSelect_RemainCompute: int = ...
	IFSelect_RemainDisplay: int = ...
	IFSelect_RemainUndo: int = ...
IFSelect_RemainForget = IFSelect_RemainMode.IFSelect_RemainForget
IFSelect_RemainCompute = IFSelect_RemainMode.IFSelect_RemainCompute
IFSelect_RemainDisplay = IFSelect_RemainMode.IFSelect_RemainDisplay
IFSelect_RemainUndo = IFSelect_RemainMode.IFSelect_RemainUndo

class IFSelect_EditValue(IntEnum):
	IFSelect_Optional: int = ...
	IFSelect_Editable: int = ...
	IFSelect_EditProtected: int = ...
	IFSelect_EditComputed: int = ...
	IFSelect_EditRead: int = ...
	IFSelect_EditDynamic: int = ...
IFSelect_Optional = IFSelect_EditValue.IFSelect_Optional
IFSelect_Editable = IFSelect_EditValue.IFSelect_Editable
IFSelect_EditProtected = IFSelect_EditValue.IFSelect_EditProtected
IFSelect_EditComputed = IFSelect_EditValue.IFSelect_EditComputed
IFSelect_EditRead = IFSelect_EditValue.IFSelect_EditRead
IFSelect_EditDynamic = IFSelect_EditValue.IFSelect_EditDynamic

class IFSelect_ReturnStatus(IntEnum):
	IFSelect_RetVoid: int = ...
	IFSelect_RetDone: int = ...
	IFSelect_RetError: int = ...
	IFSelect_RetFail: int = ...
	IFSelect_RetStop: int = ...
IFSelect_RetVoid = IFSelect_ReturnStatus.IFSelect_RetVoid
IFSelect_RetDone = IFSelect_ReturnStatus.IFSelect_RetDone
IFSelect_RetError = IFSelect_ReturnStatus.IFSelect_RetError
IFSelect_RetFail = IFSelect_ReturnStatus.IFSelect_RetFail
IFSelect_RetStop = IFSelect_ReturnStatus.IFSelect_RetStop

class IFSelect_PrintCount(IntEnum):
	IFSelect_ItemsByEntity: int = ...
	IFSelect_CountByItem: int = ...
	IFSelect_ShortByItem: int = ...
	IFSelect_ListByItem: int = ...
	IFSelect_EntitiesByItem: int = ...
	IFSelect_CountSummary: int = ...
	IFSelect_GeneralInfo: int = ...
	IFSelect_Mapping: int = ...
	IFSelect_ResultCount: int = ...
IFSelect_ItemsByEntity = IFSelect_PrintCount.IFSelect_ItemsByEntity
IFSelect_CountByItem = IFSelect_PrintCount.IFSelect_CountByItem
IFSelect_ShortByItem = IFSelect_PrintCount.IFSelect_ShortByItem
IFSelect_ListByItem = IFSelect_PrintCount.IFSelect_ListByItem
IFSelect_EntitiesByItem = IFSelect_PrintCount.IFSelect_EntitiesByItem
IFSelect_CountSummary = IFSelect_PrintCount.IFSelect_CountSummary
IFSelect_GeneralInfo = IFSelect_PrintCount.IFSelect_GeneralInfo
IFSelect_Mapping = IFSelect_PrintCount.IFSelect_Mapping
IFSelect_ResultCount = IFSelect_PrintCount.IFSelect_ResultCount

class ifselect:
	@staticmethod
	def RestoreSession(WS: IFSelect_WorkSession, file: str) -> bool: ...
	@staticmethod
	def SaveSession(WS: IFSelect_WorkSession, file: str) -> bool: ...

class IFSelect_Activator(Standard_Transient):
	def Add(self, number: int, command: str) -> None: ...
	def AddSet(self, number: int, command: str) -> None: ...
	@staticmethod
	def Adding(actor: IFSelect_Activator, number: int, command: str, mode: int) -> None: ...
	@staticmethod
	def Commands(mode: Optional[int] = -1, command: Optional[str] = "") -> TColStd_HSequenceOfAsciiString: ...
	def Do(self, number: int, pilot: IFSelect_SessionPilot) -> IFSelect_ReturnStatus: ...
	def File(self) -> str: ...
	def Group(self) -> str: ...
	def Help(self, number: int) -> str: ...
	@staticmethod
	def Mode(command: str) -> int: ...
	@staticmethod
	def Remove(command: str) -> None: ...
	@staticmethod
	def Select(command: str, actor: IFSelect_Activator) -> Tuple[bool, int]: ...
	def SetForGroup(self, group: str, file: Optional[str] = "") -> None: ...

class IFSelect_AppliedModifiers(Standard_Transient):
	def __init__(self, nbmax: int, nbent: int) -> None: ...
	def AddModif(self, modif: IFSelect_GeneralModifier) -> bool: ...
	def AddNum(self, nument: int) -> bool: ...
	def Count(self) -> int: ...
	def IsForAll(self) -> bool: ...
	def Item(self, num: int, modif: IFSelect_GeneralModifier) -> Tuple[bool, int]: ...
	def ItemList(self) -> TColStd_HSequenceOfInteger: ...
	def ItemNum(self, nument: int) -> int: ...

class IFSelect_ContextModif:
	@overload
	def __init__(self, graph: Interface_Graph, TC: Interface_CopyTool, filename: Optional[str] = "") -> None: ...
	@overload
	def __init__(self, graph: Interface_Graph, filename: Optional[str] = "") -> None: ...
	def AddCheck(self, check: Interface_Check) -> None: ...
	def AddFail(self, start: Standard_Transient, mess: str, orig: Optional[str] = "") -> None: ...
	def AddWarning(self, start: Standard_Transient, mess: str, orig: Optional[str] = "") -> None: ...
	@overload
	def CCheck(self, num: Optional[int] = 0) -> Interface_Check: ...
	@overload
	def CCheck(self, start: Standard_Transient) -> Interface_Check: ...
	def CheckList(self) -> Interface_CheckIterator: ...
	def Control(self) -> Interface_CopyControl: ...
	def FileName(self) -> str: ...
	def HasFileName(self) -> bool: ...
	def IsForAll(self) -> bool: ...
	def IsForNone(self) -> bool: ...
	def IsSelected(self, ent: Standard_Transient) -> bool: ...
	def IsTransferred(self, ent: Standard_Transient) -> bool: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def OriginalGraph(self) -> Interface_Graph: ...
	def OriginalModel(self) -> Interface_InterfaceModel: ...
	def Protocol(self) -> Interface_Protocol: ...
	def Select(self, list: Interface_EntityIterator) -> None: ...
	def SelectedCount(self) -> int: ...
	def SelectedOriginal(self) -> Interface_EntityIterator: ...
	def SelectedResult(self) -> Interface_EntityIterator: ...
	def SetProtocol(self, proto: Interface_Protocol) -> None: ...
	def Start(self) -> None: ...
	def Trace(self, mess: Optional[str] = "") -> None: ...
	def TraceModifier(self, modif: IFSelect_GeneralModifier) -> None: ...
	def ValueOriginal(self) -> Standard_Transient: ...
	def ValueResult(self) -> Standard_Transient: ...

class IFSelect_ContextWrite:
	@overload
	def __init__(self, model: Interface_InterfaceModel, proto: Interface_Protocol, applieds: IFSelect_AppliedModifiers, filename: str) -> None: ...
	@overload
	def __init__(self, hgraph: Interface_HGraph, proto: Interface_Protocol, applieds: IFSelect_AppliedModifiers, filename: str) -> None: ...
	def AddCheck(self, check: Interface_Check) -> None: ...
	def AddFail(self, start: Standard_Transient, mess: str, orig: Optional[str] = "") -> None: ...
	def AddWarning(self, start: Standard_Transient, mess: str, orig: Optional[str] = "") -> None: ...
	def AppliedModifiers(self) -> IFSelect_AppliedModifiers: ...
	@overload
	def CCheck(self, num: Optional[int] = 0) -> Interface_Check: ...
	@overload
	def CCheck(self, start: Standard_Transient) -> Interface_Check: ...
	def CheckList(self) -> Interface_CheckIterator: ...
	def FileModifier(self) -> IFSelect_GeneralModifier: ...
	def FileName(self) -> str: ...
	def Graph(self) -> Interface_Graph: ...
	def IsForAll(self) -> bool: ...
	def IsForNone(self) -> bool: ...
	def Model(self) -> Interface_InterfaceModel: ...
	def More(self) -> bool: ...
	def NbEntities(self) -> int: ...
	def NbModifiers(self) -> int: ...
	def Next(self) -> None: ...
	def Protocol(self) -> Interface_Protocol: ...
	def SetModifier(self, numod: int) -> bool: ...
	def Start(self) -> None: ...
	def Value(self) -> Standard_Transient: ...

class IFSelect_Dispatch(Standard_Transient):
	def CanHaveRemainder(self) -> bool: ...
	def FinalSelection(self) -> IFSelect_Selection: ...
	def GetEntities(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def HasRootName(self) -> bool: ...
	def Label(self) -> TCollection_AsciiString: ...
	def LimitedMax(self, nbent: int) -> Tuple[bool, int]: ...
	def Packeted(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def Remainder(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def RootName(self) -> TCollection_HAsciiString: ...
	def Selections(self) -> IFSelect_SelectionIterator: ...
	def SetFinalSelection(self, sel: IFSelect_Selection) -> None: ...
	def SetRootName(self, name: TCollection_HAsciiString) -> None: ...

class IFSelect_EditForm(Standard_Transient):
	@overload
	def __init__(self, editor: IFSelect_Editor, readonly: bool, undoable: bool, label: Optional[str] = "") -> None: ...
	@overload
	def __init__(self, editor: IFSelect_Editor, nums: TColStd_SequenceOfInteger, readonly: bool, undoable: bool, label: Optional[str] = "") -> None: ...
	def Apply(self) -> bool: ...
	def ApplyData(self, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...
	def ClearData(self) -> None: ...
	def ClearEdit(self, num: Optional[int] = 0) -> None: ...
	def GetEditKeepStatus(self) -> bool: ...
	def SetEditKeepStatus(self, value: bool) -> None: ...
	def EditedList(self, num: int) -> TColStd_HSequenceOfHAsciiString: ...
	def EditedValue(self, num: int) -> TCollection_HAsciiString: ...
	def Editor(self) -> IFSelect_Editor: ...
	def Entity(self) -> Standard_Transient: ...
	def IsComplete(self) -> bool: ...
	def IsLoaded(self) -> bool: ...
	def IsModified(self, num: int) -> bool: ...
	def IsTouched(self, num: int) -> bool: ...
	def Label(self) -> str: ...
	def ListEditor(self, num: int) -> IFSelect_ListEditor: ...
	@overload
	def LoadData(self, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...
	@overload
	def LoadData(self) -> bool: ...
	def LoadDefault(self) -> None: ...
	def LoadEntity(self, ent: Standard_Transient) -> bool: ...
	def LoadList(self, num: int, list: TColStd_HSequenceOfHAsciiString) -> None: ...
	def LoadModel(self, model: Interface_InterfaceModel) -> bool: ...
	def LoadValue(self, num: int, val: TCollection_HAsciiString) -> None: ...
	def Model(self) -> Interface_InterfaceModel: ...
	def Modify(self, num: int, newval: TCollection_HAsciiString, enforce: Optional[bool] = False) -> bool: ...
	def ModifyList(self, num: int, edited: IFSelect_ListEditor, enforce: Optional[bool] = False) -> bool: ...
	def ModifyListValue(self, num: int, list: TColStd_HSequenceOfHAsciiString, enforce: Optional[bool] = False) -> bool: ...
	def NameNumber(self, name: str) -> int: ...
	def NameRank(self, name: str) -> int: ...
	def NbValues(self, editable: bool) -> int: ...
	def NumberFromRank(self, rank: int) -> int: ...
	def OriginalList(self, num: int) -> TColStd_HSequenceOfHAsciiString: ...
	def OriginalValue(self, num: int) -> TCollection_HAsciiString: ...
	def RankFromNumber(self, number: int) -> int: ...
	def Recognize(self) -> bool: ...
	def SetData(self, ent: Standard_Transient, model: Interface_InterfaceModel) -> None: ...
	def SetEntity(self, ent: Standard_Transient) -> None: ...
	def SetModel(self, model: Interface_InterfaceModel) -> None: ...
	def Touch(self, num: int, newval: TCollection_HAsciiString) -> bool: ...
	def TouchList(self, num: int, newlist: TColStd_HSequenceOfHAsciiString) -> bool: ...
	def Undo(self) -> bool: ...

class IFSelect_Editor(Standard_Transient):
	def Apply(self, form: IFSelect_EditForm, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...
	def EditMode(self, num: int) -> IFSelect_EditValue: ...
	def Form(self, readonly: bool, undoable: Optional[bool] = True) -> IFSelect_EditForm: ...
	def IsList(self, num: int) -> bool: ...
	def Label(self) -> TCollection_AsciiString: ...
	def ListEditor(self, num: int) -> IFSelect_ListEditor: ...
	def ListValue(self, form: IFSelect_EditForm, num: int) -> TColStd_HSequenceOfHAsciiString: ...
	def Load(self, form: IFSelect_EditForm, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...
	def MaxList(self, num: int) -> int: ...
	def MaxNameLength(self, what: int) -> int: ...
	def Name(self, num: int, isshort: Optional[bool] = False) -> str: ...
	def NameNumber(self, name: str) -> int: ...
	def NbValues(self) -> int: ...
	def Recognize(self, form: IFSelect_EditForm) -> bool: ...
	def SetList(self, num: int, max: Optional[int] = 0) -> None: ...
	def SetValue(self, num: int, typval: Interface_TypedValue, shortname: Optional[str] = "", accessmode: Optional[IFSelect_EditValue] = IFSelect_Editable) -> None: ...
	def StringValue(self, form: IFSelect_EditForm, num: int) -> TCollection_HAsciiString: ...
	def TypedValue(self, num: int) -> Interface_TypedValue: ...
	def Update(self, form: IFSelect_EditForm, num: int, newval: TCollection_HAsciiString, enforce: bool) -> bool: ...
	def UpdateList(self, form: IFSelect_EditForm, num: int, newlist: TColStd_HSequenceOfHAsciiString, enforce: bool) -> bool: ...

class IFSelect_Functions:
	@staticmethod
	def GiveDispatch(WS: IFSelect_WorkSession, name: str, mode: Optional[bool] = True) -> IFSelect_Dispatch: ...
	@staticmethod
	def GiveEntity(WS: IFSelect_WorkSession, name: Optional[str] = "") -> Standard_Transient: ...
	@staticmethod
	def GiveEntityNumber(WS: IFSelect_WorkSession, name: Optional[str] = "") -> int: ...
	@staticmethod
	def GiveList(WS: IFSelect_WorkSession, first: Optional[str] = "", second: Optional[str] = "") -> TColStd_HSequenceOfTransient: ...
	@staticmethod
	def Init() -> None: ...

class IFSelect_GeneralModifier(Standard_Transient):
	def Applies(self, disp: IFSelect_Dispatch) -> bool: ...
	def Dispatch(self) -> IFSelect_Dispatch: ...
	def HasSelection(self) -> bool: ...
	def Label(self) -> TCollection_AsciiString: ...
	def MayChangeGraph(self) -> bool: ...
	def ResetSelection(self) -> None: ...
	def Selection(self) -> IFSelect_Selection: ...
	def SetDispatch(self, disp: IFSelect_Dispatch) -> None: ...
	def SetSelection(self, sel: IFSelect_Selection) -> None: ...

class IFSelect_IntParam(Standard_Transient):
	def __init__(self) -> None: ...
	def SetStaticName(self, statname: str) -> None: ...
	def SetValue(self, val: int) -> None: ...
	def Value(self) -> int: ...

class IFSelect_ListEditor(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, def_: Interface_TypedValue, max: Optional[int] = 0) -> None: ...
	def AddValue(self, val: TCollection_HAsciiString, atnum: Optional[int] = 0) -> bool: ...
	def ClearEdit(self) -> None: ...
	def EditedValues(self) -> TColStd_HSequenceOfHAsciiString: ...
	def IsAdded(self, num: int) -> bool: ...
	def IsChanged(self, num: int) -> bool: ...
	def IsModified(self, num: int) -> bool: ...
	def IsTouched(self) -> bool: ...
	def LoadEdited(self, list: TColStd_HSequenceOfHAsciiString) -> bool: ...
	def LoadModel(self, model: Interface_InterfaceModel) -> None: ...
	def LoadValues(self, vals: TColStd_HSequenceOfHAsciiString) -> None: ...
	def NbValues(self, edited: Optional[bool] = True) -> int: ...
	def OriginalValues(self) -> TColStd_HSequenceOfHAsciiString: ...
	def Remove(self, num: Optional[int] = 0, howmany: Optional[int] = 1) -> bool: ...
	def SetTouched(self) -> None: ...
	def SetValue(self, num: int, val: TCollection_HAsciiString) -> bool: ...
	def Value(self, num: int, edited: Optional[bool] = True) -> TCollection_HAsciiString: ...

class IFSelect_ModelCopier(Standard_Transient):
	def __init__(self) -> None: ...
	def AddFile(self, filename: TCollection_AsciiString, content: Interface_InterfaceModel) -> bool: ...
	def AddSentFile(self, filename: str) -> None: ...
	def AppliedModifiers(self, num: int) -> IFSelect_AppliedModifiers: ...
	def BeginSentFiles(self, sho: IFSelect_ShareOut, record: bool) -> None: ...
	def ClearAppliedModifiers(self, num: int) -> bool: ...
	def ClearFile(self, num: int) -> bool: ...
	def ClearResult(self) -> None: ...
	def CopiedRemaining(self, G: Interface_Graph, WL: IFSelect_WorkLibrary, TC: Interface_CopyTool, newmod: Interface_InterfaceModel) -> None: ...
	def Copy(self, eval: IFSelect_ShareOutResult, WL: IFSelect_WorkLibrary, protocol: Interface_Protocol) -> Interface_CheckIterator: ...
	def FileModel(self, num: int) -> Interface_InterfaceModel: ...
	def FileName(self, num: int) -> TCollection_AsciiString: ...
	def NameFile(self, num: int, filename: TCollection_AsciiString) -> bool: ...
	def NbFiles(self) -> int: ...
	def Send(self, eval: IFSelect_ShareOutResult, WL: IFSelect_WorkLibrary, protocol: Interface_Protocol) -> Interface_CheckIterator: ...
	def SendAll(self, filename: str, G: Interface_Graph, WL: IFSelect_WorkLibrary, protocol: Interface_Protocol) -> Interface_CheckIterator: ...
	def SendCopied(self, WL: IFSelect_WorkLibrary, protocol: Interface_Protocol) -> Interface_CheckIterator: ...
	def SendSelected(self, filename: str, G: Interface_Graph, WL: IFSelect_WorkLibrary, protocol: Interface_Protocol, iter: Interface_EntityIterator) -> Interface_CheckIterator: ...
	def SentFiles(self) -> TColStd_HSequenceOfHAsciiString: ...
	def SetAppliedModifiers(self, num: int, applied: IFSelect_AppliedModifiers) -> bool: ...
	def SetRemaining(self, CG: Interface_Graph) -> bool: ...
	def SetShareOut(self, sho: IFSelect_ShareOut) -> None: ...

class IFSelect_PacketList(Standard_Transient):
	def __init__(self, model: Interface_InterfaceModel) -> None: ...
	def Add(self, ent: Standard_Transient) -> None: ...
	def AddList(self, list: TColStd_HSequenceOfTransient) -> None: ...
	def AddPacket(self) -> None: ...
	def Duplicated(self, count: int, andmore: bool) -> Interface_EntityIterator: ...
	def Entities(self, numpack: int) -> Interface_EntityIterator: ...
	def HighestDuplicationCount(self) -> int: ...
	def Model(self) -> Interface_InterfaceModel: ...
	def Name(self) -> str: ...
	def NbDuplicated(self, count: int, andmore: bool) -> int: ...
	def NbEntities(self, numpack: int) -> int: ...
	def NbPackets(self) -> int: ...
	def SetName(self, name: str) -> None: ...

class IFSelect_Selection(Standard_Transient):
	def CompleteResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def FillIterator(self, iter: IFSelect_SelectionIterator) -> None: ...
	def Label(self) -> TCollection_AsciiString: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def UniqueResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...

class IFSelect_SelectionIterator:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, sel: IFSelect_Selection) -> None: ...
	def AddFromIter(self, iter: IFSelect_SelectionIterator) -> None: ...
	def AddItem(self, sel: IFSelect_Selection) -> None: ...
	def AddList(self, list: IFSelect_TSeqOfSelection) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Value(self) -> IFSelect_Selection: ...

class IFSelect_SessionDumper(Standard_Transient):
	@staticmethod
	def First() -> IFSelect_SessionDumper: ...
	def Next(self) -> IFSelect_SessionDumper: ...
	def ReadOwn(self, file: IFSelect_SessionFile, type: TCollection_AsciiString, item: Standard_Transient) -> bool: ...
	def WriteOwn(self, file: IFSelect_SessionFile, item: Standard_Transient) -> bool: ...

class IFSelect_SessionFile:
	@overload
	def __init__(self, WS: IFSelect_WorkSession) -> None: ...
	@overload
	def __init__(self, WS: IFSelect_WorkSession, filename: str) -> None: ...
	def AddItem(self, item: Standard_Transient, active: Optional[bool] = True) -> None: ...
	def AddLine(self, line: str) -> None: ...
	def ClearLines(self) -> None: ...
	def Destroy(self) -> None: ...
	def IsDone(self) -> bool: ...
	def IsText(self, num: int) -> bool: ...
	def IsVoid(self, num: int) -> bool: ...
	def ItemValue(self, num: int) -> Standard_Transient: ...
	def Line(self, num: int) -> TCollection_AsciiString: ...
	def NbLines(self) -> int: ...
	def NbParams(self) -> int: ...
	def NewItem(self, ident: int, par: Standard_Transient) -> None: ...
	def ParamValue(self, num: int) -> TCollection_AsciiString: ...
	def Read(self, filename: str) -> int: ...
	def ReadEnd(self) -> int: ...
	def ReadFile(self, name: str) -> bool: ...
	def ReadLine(self) -> bool: ...
	def ReadOwn(self, item: Standard_Transient) -> bool: ...
	def ReadSession(self) -> int: ...
	def RecognizeFile(self, headerline: str) -> bool: ...
	def RemoveLastLine(self) -> None: ...
	def SendItem(self, par: Standard_Transient) -> None: ...
	def SendText(self, text: str) -> None: ...
	def SendVoid(self) -> None: ...
	def SetLastGeneral(self, lastgen: int) -> None: ...
	def SetOwn(self, mode: bool) -> None: ...
	def SplitLine(self, line: str) -> None: ...
	def TextValue(self, num: int) -> TCollection_AsciiString: ...
	def WorkSession(self) -> IFSelect_WorkSession: ...
	def Write(self, filename: str) -> int: ...
	def WriteEnd(self) -> int: ...
	def WriteFile(self, name: str) -> bool: ...
	def WriteLine(self, line: str, follow: Optional[str] = 0) -> None: ...
	def WriteOwn(self, item: Standard_Transient) -> bool: ...
	def WriteSession(self) -> int: ...

class IFSelect_ShareOut(Standard_Transient):
	def __init__(self) -> None: ...
	def AddDispatch(self, disp: IFSelect_Dispatch) -> None: ...
	def AddModif(self, modifier: IFSelect_GeneralModifier, formodel: bool, atnum: Optional[int] = 0) -> None: ...
	@overload
	def AddModifier(self, modifier: IFSelect_GeneralModifier, atnum: int) -> None: ...
	@overload
	def AddModifier(self, modifier: IFSelect_GeneralModifier, dispnum: int, atnum: int) -> None: ...
	def ChangeModifierRank(self, formodel: bool, befor: int, after: int) -> bool: ...
	def Clear(self, onlydisp: bool) -> None: ...
	def ClearResult(self, alsoname: bool) -> None: ...
	def DefaultRootName(self) -> TCollection_HAsciiString: ...
	def Dispatch(self, num: int) -> IFSelect_Dispatch: ...
	def DispatchRank(self, disp: IFSelect_Dispatch) -> int: ...
	def Extension(self) -> TCollection_HAsciiString: ...
	def FileName(self, dnum: int, pnum: int, nbpack: Optional[int] = 0) -> TCollection_AsciiString: ...
	def GeneralModifier(self, formodel: bool, num: int) -> IFSelect_GeneralModifier: ...
	def HasRootName(self, num: int) -> bool: ...
	def LastRun(self) -> int: ...
	def ModelModifier(self, num: int) -> IFSelect_Modifier: ...
	def ModifierRank(self, modifier: IFSelect_GeneralModifier) -> int: ...
	def NbDispatches(self) -> int: ...
	def NbModifiers(self, formodel: bool) -> int: ...
	def Prefix(self) -> TCollection_HAsciiString: ...
	def RemoveDispatch(self, rank: int) -> bool: ...
	def RemoveItem(self, item: Standard_Transient) -> bool: ...
	def RemoveModifier(self, formodel: bool, num: int) -> bool: ...
	def RootName(self, num: int) -> TCollection_HAsciiString: ...
	def RootNumber(self, name: TCollection_HAsciiString) -> int: ...
	def SetDefaultRootName(self, defrt: TCollection_HAsciiString) -> bool: ...
	def SetExtension(self, ext: TCollection_HAsciiString) -> None: ...
	def SetLastRun(self, last: int) -> None: ...
	def SetPrefix(self, pref: TCollection_HAsciiString) -> None: ...
	def SetRootName(self, num: int, name: TCollection_HAsciiString) -> bool: ...

class IFSelect_ShareOutResult:
	@overload
	def __init__(self, sho: IFSelect_ShareOut, mod: Interface_InterfaceModel) -> None: ...
	@overload
	def __init__(self, sho: IFSelect_ShareOut, G: Interface_Graph) -> None: ...
	@overload
	def __init__(self, disp: IFSelect_Dispatch, mod: Interface_InterfaceModel) -> None: ...
	@overload
	def __init__(self, disp: IFSelect_Dispatch, G: Interface_Graph) -> None: ...
	def Dispatch(self) -> IFSelect_Dispatch: ...
	def DispatchRank(self) -> int: ...
	def Evaluate(self) -> None: ...
	def FileName(self) -> TCollection_AsciiString: ...
	def Graph(self) -> Interface_Graph: ...
	def More(self) -> bool: ...
	def NbPackets(self) -> int: ...
	def Next(self) -> None: ...
	def NextDispatch(self) -> None: ...
	def PacketContent(self) -> Interface_EntityIterator: ...
	def PacketRoot(self) -> Interface_EntityIterator: ...
	def Packets(self, complete: Optional[bool] = True) -> IFSelect_PacketList: ...
	def PacketsInDispatch(self) -> Tuple[int, int]: ...
	def Prepare(self) -> None: ...
	def Reset(self) -> None: ...
	def ShareOut(self) -> IFSelect_ShareOut: ...

class IFSelect_Signature(Interface_SignType):
	def AddCase(self, acase: str) -> None: ...
	def CaseList(self) -> TColStd_HSequenceOfAsciiString: ...
	@staticmethod
	def IntValue(val: int) -> str: ...
	def IsIntCase(self) -> Tuple[bool, bool, int, bool, int]: ...
	def Label(self) -> TCollection_AsciiString: ...
	@staticmethod
	def MatchValue(val: str, text: TCollection_AsciiString, exact: bool) -> bool: ...
	def Matches(self, ent: Standard_Transient, model: Interface_InterfaceModel, text: TCollection_AsciiString, exact: bool) -> bool: ...
	def Name(self) -> str: ...
	def SetIntCase(self, hasmin: bool, valmin: int, hasmax: bool, valmax: int) -> None: ...

class IFSelect_SignatureList(Standard_Transient):
	def __init__(self, withlist: Optional[bool] = False) -> None: ...
	def Add(self, ent: Standard_Transient, sign: str) -> None: ...
	def Clear(self) -> None: ...
	def Entities(self, sign: str) -> TColStd_HSequenceOfTransient: ...
	def HasEntities(self) -> bool: ...
	def LastValue(self) -> str: ...
	def List(self, root: Optional[str] = "") -> TColStd_HSequenceOfHAsciiString: ...
	def GetModeSignOnly(self) -> bool: ...
	def SetModeSignOnly(self, value: bool) -> None: ...
	def Name(self) -> str: ...
	def NbNulls(self) -> int: ...
	def NbTimes(self, sign: str) -> int: ...
	def SetList(self, withlist: bool) -> None: ...
	def SetName(self, name: str) -> None: ...

class IFSelect_Transformer(Standard_Transient):
	def ChangeProtocol(self, newproto: Interface_Protocol) -> bool: ...
	def Label(self) -> TCollection_AsciiString: ...
	def Perform(self, G: Interface_Graph, protocol: Interface_Protocol, checks: Interface_CheckIterator, newmod: Interface_InterfaceModel) -> bool: ...
	def Updated(self, entfrom: Standard_Transient, entto: Standard_Transient) -> bool: ...

class IFSelect_WorkLibrary(Standard_Transient):
	def CopyModel(self, original: Interface_InterfaceModel, newmodel: Interface_InterfaceModel, list: Interface_EntityIterator, TC: Interface_CopyTool) -> bool: ...
	def DumpHelp(self, level: int) -> str: ...
	def DumpLevels(self) -> Tuple[int, int]: ...
	def ReadFile(self, name: str, model: Interface_InterfaceModel, protocol: Interface_Protocol) -> int: ...
	def SetDumpHelp(self, level: int, help: str) -> None: ...
	def SetDumpLevels(self, def_: int, max: int) -> None: ...
	def WriteFile(self, ctx: IFSelect_ContextWrite) -> bool: ...

class IFSelect_WorkSession(Standard_Transient):
	def __init__(self) -> None: ...
	def AddItem(self, item: Standard_Transient, active: Optional[bool] = True) -> int: ...
	def AddNamedItem(self, name: str, item: Standard_Transient, active: Optional[bool] = True) -> int: ...
	def AppliedDispatches(self) -> TColStd_HSequenceOfInteger: ...
	def BeginSentFiles(self, record: bool) -> None: ...
	def CategoryName(self, ent: Standard_Transient) -> str: ...
	def CategoryNumber(self, ent: Standard_Transient) -> int: ...
	def ChangeModifierRank(self, formodel: bool, before: int, after: int) -> bool: ...
	def CheckOne(self, ent: Standard_Transient, complete: Optional[bool] = True) -> Interface_CheckIterator: ...
	def ClearData(self, mode: int) -> None: ...
	def ClearFile(self) -> None: ...
	def ClearFinalModifiers(self) -> None: ...
	def ClearItems(self) -> None: ...
	def ClearShareOut(self, onlydisp: bool) -> None: ...
	def CombineAdd(self, selcomb: IFSelect_Selection, seladd: IFSelect_Selection, atnum: Optional[int] = 0) -> int: ...
	def CombineRemove(self, selcomb: IFSelect_Selection, selrem: IFSelect_Selection) -> bool: ...
	def ComputeCheck(self, enforce: Optional[bool] = False) -> bool: ...
	def ComputeCounter(self, counter: IFSelect_SignCounter, forced: Optional[bool] = False) -> bool: ...
	def ComputeCounterFromList(self, counter: IFSelect_SignCounter, list: TColStd_HSequenceOfTransient, clear: Optional[bool] = True) -> bool: ...
	def ComputeGraph(self, enforce: Optional[bool] = False) -> bool: ...
	def DefaultFileRoot(self) -> TCollection_HAsciiString: ...
	def Dispatch(self, id: int) -> IFSelect_Dispatch: ...
	def DispatchRank(self, disp: IFSelect_Dispatch) -> int: ...
	def DumpSelection(self, sel: IFSelect_Selection) -> None: ...
	def DumpShare(self) -> None: ...
	def EntityLabel(self, ent: Standard_Transient) -> TCollection_HAsciiString: ...
	def EntityName(self, ent: Standard_Transient) -> TCollection_HAsciiString: ...
	def ErrorHandle(self) -> bool: ...
	def EvalSelection(self, sel: IFSelect_Selection) -> Interface_EntityIterator: ...
	def EvalSplit(self) -> IFSelect_PacketList: ...
	def EvaluateComplete(self, mode: Optional[int] = 0) -> None: ...
	def EvaluateDispatch(self, disp: IFSelect_Dispatch, mode: Optional[int] = 0) -> None: ...
	def EvaluateFile(self) -> None: ...
	def EvaluateSelection(self, sel: IFSelect_Selection) -> None: ...
	def FileExtension(self) -> TCollection_HAsciiString: ...
	def FileModel(self, num: int) -> Interface_InterfaceModel: ...
	def FileName(self, num: int) -> TCollection_AsciiString: ...
	def FilePrefix(self) -> TCollection_HAsciiString: ...
	def FileRoot(self, disp: IFSelect_Dispatch) -> TCollection_HAsciiString: ...
	def FinalModifierIdents(self, formodel: bool) -> TColStd_HSequenceOfInteger: ...
	def GeneralModifier(self, id: int) -> IFSelect_GeneralModifier: ...
	def GetModeStat(self) -> bool: ...
	def GiveFileComplete(self, file: str) -> str: ...
	def GiveFileRoot(self, file: str) -> str: ...
	@overload
	def GiveList(self, obj: Standard_Transient) -> TColStd_HSequenceOfTransient: ...
	@overload
	def GiveList(self, first: str, second: Optional[str] = "") -> TColStd_HSequenceOfTransient: ...
	def GiveListCombined(self, l1: TColStd_HSequenceOfTransient, l2: TColStd_HSequenceOfTransient, mode: int) -> TColStd_HSequenceOfTransient: ...
	def GiveListFromList(self, selname: str, ent: Standard_Transient) -> TColStd_HSequenceOfTransient: ...
	def GiveSelection(self, selname: str) -> IFSelect_Selection: ...
	def Graph(self) -> Interface_Graph: ...
	def HGraph(self) -> Interface_HGraph: ...
	def HasModel(self) -> bool: ...
	def HasName(self, item: Standard_Transient) -> bool: ...
	def IntParam(self, id: int) -> IFSelect_IntParam: ...
	def IntValue(self, it: IFSelect_IntParam) -> int: ...
	def IsLoaded(self) -> bool: ...
	def IsReversedSelectExtract(self, sel: IFSelect_Selection) -> bool: ...
	def Item(self, id: int) -> Standard_Transient: ...
	def ItemIdent(self, item: Standard_Transient) -> int: ...
	def ItemIdents(self, type: Standard_Type) -> TColStd_HSequenceOfInteger: ...
	def ItemLabel(self, id: int) -> TCollection_HAsciiString: ...
	def ItemNames(self, type: Standard_Type) -> TColStd_HSequenceOfHAsciiString: ...
	def ItemNamesForLabel(self, label: str) -> TColStd_HSequenceOfHAsciiString: ...
	def ItemSelection(self, item: Standard_Transient) -> IFSelect_Selection: ...
	def LastRunCheckList(self) -> Interface_CheckIterator: ...
	def ListFinalModifiers(self, formodel: bool) -> None: ...
	def ListItems(self, label: Optional[str] = "") -> None: ...
	def LoadedFile(self) -> str: ...
	def MaxIdent(self) -> int: ...
	def MaxSendingCount(self) -> int: ...
	def Model(self) -> Interface_InterfaceModel: ...
	def ModelCheckList(self, complete: Optional[bool] = True) -> Interface_CheckIterator: ...
	def ModelCopier(self) -> IFSelect_ModelCopier: ...
	def ModelModifier(self, id: int) -> IFSelect_Modifier: ...
	def ModifierRank(self, item: IFSelect_GeneralModifier) -> int: ...
	def Name(self, item: Standard_Transient) -> TCollection_HAsciiString: ...
	def NameIdent(self, name: str) -> int: ...
	@overload
	def NamedItem(self, name: str) -> Standard_Transient: ...
	@overload
	def NamedItem(self, name: TCollection_HAsciiString) -> Standard_Transient: ...
	def NbFiles(self) -> int: ...
	def NbFinalModifiers(self, formodel: bool) -> int: ...
	def NbSources(self, sel: IFSelect_Selection) -> int: ...
	def NbStartingEntities(self) -> int: ...
	def NewIntParam(self, name: Optional[str] = "") -> IFSelect_IntParam: ...
	def NewParamFromStatic(self, statname: str, name: Optional[str] = "") -> Standard_Transient: ...
	def NewSelectPointed(self, list: TColStd_HSequenceOfTransient, name: str) -> IFSelect_Selection: ...
	def NewTextParam(self, name: Optional[str] = "") -> TCollection_HAsciiString: ...
	def NewTransformStandard(self, copy: bool, name: Optional[str] = "") -> IFSelect_Transformer: ...
	def NextIdentForLabel(self, label: str, id: int, mode: Optional[int] = 0) -> int: ...
	def NumberFromLabel(self, val: str, afternum: Optional[int] = 0) -> int: ...
	def Protocol(self) -> Interface_Protocol: ...
	def QueryCheckList(self, chl: Interface_CheckIterator) -> None: ...
	def QueryCheckStatus(self, ent: Standard_Transient) -> int: ...
	def QueryParent(self, entdad: Standard_Transient, entson: Standard_Transient) -> int: ...
	def ReadFile(self, filename: str) -> IFSelect_ReturnStatus: ...
	def RemoveItem(self, item: Standard_Transient) -> bool: ...
	def RemoveName(self, name: str) -> bool: ...
	def RemoveNamedItem(self, name: str) -> bool: ...
	def ResetAppliedModifier(self, modif: IFSelect_GeneralModifier) -> bool: ...
	def ResetItemSelection(self, item: Standard_Transient) -> bool: ...
	def RunModifier(self, modif: IFSelect_Modifier, copy: bool) -> int: ...
	def RunModifierSelected(self, modif: IFSelect_Modifier, sel: IFSelect_Selection, copy: bool) -> int: ...
	def RunTransformer(self, transf: IFSelect_Transformer) -> int: ...
	def Selection(self, id: int) -> IFSelect_Selection: ...
	def SelectionResult(self, sel: IFSelect_Selection) -> TColStd_HSequenceOfTransient: ...
	def SelectionResultFromList(self, sel: IFSelect_Selection, list: TColStd_HSequenceOfTransient) -> TColStd_HSequenceOfTransient: ...
	def SendAll(self, filename: str, computegraph: Optional[bool] = False) -> IFSelect_ReturnStatus: ...
	def SendSelected(self, filename: str, sel: IFSelect_Selection, computegraph: Optional[bool] = False) -> IFSelect_ReturnStatus: ...
	def SendSplit(self) -> bool: ...
	def SentFiles(self) -> TColStd_HSequenceOfHAsciiString: ...
	def SentList(self, count: Optional[int] = -1) -> Interface_EntityIterator: ...
	def SetActive(self, item: Standard_Transient, mode: bool) -> bool: ...
	def SetAppliedModifier(self, modif: IFSelect_GeneralModifier, item: Standard_Transient) -> bool: ...
	def SetControl(self, sel: IFSelect_Selection, sc: IFSelect_Selection, formain: Optional[bool] = True) -> bool: ...
	def SetDefaultFileRoot(self, name: str) -> bool: ...
	def SetErrorHandle(self, toHandle: bool) -> None: ...
	def SetFileExtension(self, name: str) -> None: ...
	def SetFilePrefix(self, name: str) -> None: ...
	def SetFileRoot(self, disp: IFSelect_Dispatch, name: str) -> bool: ...
	def SetInputSelection(self, sel: IFSelect_Selection, input: IFSelect_Selection) -> bool: ...
	def SetIntValue(self, it: IFSelect_IntParam, val: int) -> bool: ...
	def SetItemSelection(self, item: Standard_Transient, sel: IFSelect_Selection) -> bool: ...
	def SetLibrary(self, theLib: IFSelect_WorkLibrary) -> None: ...
	def SetLoadedFile(self, theFileName: str) -> None: ...
	def SetModeStat(self, theMode: bool) -> None: ...
	def SetModel(self, model: Interface_InterfaceModel, clearpointed: Optional[bool] = True) -> None: ...
	def SetModelContent(self, sel: IFSelect_Selection, keep: bool) -> bool: ...
	def SetModelCopier(self, copier: IFSelect_ModelCopier) -> None: ...
	def SetProtocol(self, protocol: Interface_Protocol) -> None: ...
	def SetRemaining(self, mode: IFSelect_RemainMode) -> bool: ...
	def SetSelectPointed(self, sel: IFSelect_Selection, list: TColStd_HSequenceOfTransient, mode: int) -> bool: ...
	def SetShareOut(self, shareout: IFSelect_ShareOut) -> None: ...
	def SetSignType(self, signtype: IFSelect_Signature) -> None: ...
	def SetTextValue(self, par: TCollection_HAsciiString, val: str) -> bool: ...
	def ShareOut(self) -> IFSelect_ShareOut: ...
	def Shareds(self, ent: Standard_Transient) -> TColStd_HSequenceOfTransient: ...
	def Sharings(self, ent: Standard_Transient) -> TColStd_HSequenceOfTransient: ...
	def SignCounter(self, id: int) -> IFSelect_SignCounter: ...
	def SignType(self) -> IFSelect_Signature: ...
	def SignValue(self, sign: IFSelect_Signature, ent: Standard_Transient) -> str: ...
	def Signature(self, id: int) -> IFSelect_Signature: ...
	def Source(self, sel: IFSelect_Selection, num: Optional[int] = 1) -> IFSelect_Selection: ...
	def Sources(self, sel: IFSelect_Selection) -> IFSelect_SelectionIterator: ...
	def StartingEntity(self, num: int) -> Standard_Transient: ...
	def StartingNumber(self, ent: Standard_Transient) -> int: ...
	def TextParam(self, id: int) -> TCollection_HAsciiString: ...
	def TextValue(self, par: TCollection_HAsciiString) -> TCollection_AsciiString: ...
	def ToggleSelectExtract(self, sel: IFSelect_Selection) -> bool: ...
	def TraceDumpEntity(self, ent: Standard_Transient, level: int) -> None: ...
	def TraceDumpModel(self, mode: int) -> None: ...
	def TraceStatics(self, use: int, mode: Optional[int] = 0) -> None: ...
	def Transformer(self, id: int) -> IFSelect_Transformer: ...
	def UsesAppliedModifier(self, modif: IFSelect_GeneralModifier) -> Standard_Transient: ...
	def ValidityName(self, ent: Standard_Transient) -> str: ...
	def WorkLibrary(self) -> IFSelect_WorkLibrary: ...
	@overload
	def WriteFile(self, filename: str) -> IFSelect_ReturnStatus: ...
	@overload
	def WriteFile(self, filename: str, sel: IFSelect_Selection) -> IFSelect_ReturnStatus: ...

class IFSelect_Act(IFSelect_Activator):
	def __init__(self, name: str, help: str, func: IFSelect_ActFunc) -> None: ...
	@staticmethod
	def AddFSet(name: str, help: str, func: IFSelect_ActFunc) -> None: ...
	@staticmethod
	def AddFunc(name: str, help: str, func: IFSelect_ActFunc) -> None: ...
	def Do(self, number: int, pilot: IFSelect_SessionPilot) -> IFSelect_ReturnStatus: ...
	def Help(self, number: int) -> str: ...
	@staticmethod
	def SetGroup(group: str, file: Optional[str] = "") -> None: ...

class IFSelect_BasicDumper(IFSelect_SessionDumper):
	def __init__(self) -> None: ...
	def ReadOwn(self, file: IFSelect_SessionFile, type: TCollection_AsciiString, item: Standard_Transient) -> bool: ...
	def WriteOwn(self, file: IFSelect_SessionFile, item: Standard_Transient) -> bool: ...

class IFSelect_CheckCounter(IFSelect_SignatureList):
	def __init__(self, withlist: Optional[bool] = False) -> None: ...
	def Analyse(self, list: Interface_CheckIterator, model: Interface_InterfaceModel, original: Optional[bool] = False, failsonly: Optional[bool] = False) -> None: ...
	def SetSignature(self, sign: MoniTool_SignText) -> None: ...
	def Signature(self) -> MoniTool_SignText: ...

class IFSelect_DispGlobal(IFSelect_Dispatch):
	def __init__(self) -> None: ...
	def Label(self) -> TCollection_AsciiString: ...
	def LimitedMax(self, nbent: int) -> Tuple[bool, int]: ...

class IFSelect_DispPerCount(IFSelect_Dispatch):
	def __init__(self) -> None: ...
	def Count(self) -> IFSelect_IntParam: ...
	def CountValue(self) -> int: ...
	def Label(self) -> TCollection_AsciiString: ...
	def LimitedMax(self, nbent: int) -> Tuple[bool, int]: ...
	def SetCount(self, count: IFSelect_IntParam) -> None: ...

class IFSelect_DispPerFiles(IFSelect_Dispatch):
	def __init__(self) -> None: ...
	def Count(self) -> IFSelect_IntParam: ...
	def CountValue(self) -> int: ...
	def Label(self) -> TCollection_AsciiString: ...
	def LimitedMax(self, nbent: int) -> Tuple[bool, int]: ...
	def SetCount(self, count: IFSelect_IntParam) -> None: ...

class IFSelect_DispPerOne(IFSelect_Dispatch):
	def __init__(self) -> None: ...
	def Label(self) -> TCollection_AsciiString: ...
	def LimitedMax(self, nbent: int) -> Tuple[bool, int]: ...

class IFSelect_DispPerSignature(IFSelect_Dispatch):
	def __init__(self) -> None: ...
	def Label(self) -> TCollection_AsciiString: ...
	def LimitedMax(self, nbent: int) -> Tuple[bool, int]: ...
	def SetSignCounter(self, sign: IFSelect_SignCounter) -> None: ...
	def SignCounter(self) -> IFSelect_SignCounter: ...
	def SignName(self) -> str: ...

class IFSelect_Modifier(IFSelect_GeneralModifier):
	def Perform(self, ctx: IFSelect_ContextModif, target: Interface_InterfaceModel, protocol: Interface_Protocol, TC: Interface_CopyTool) -> None: ...

class IFSelect_ParamEditor(IFSelect_Editor):
	def __init__(self, nbmax: Optional[int] = 100, label: Optional[str] = "") -> None: ...
	def AddConstantText(self, val: str, shortname: str, completename: Optional[str] = "") -> None: ...
	def AddValue(self, val: Interface_TypedValue, shortname: Optional[str] = "") -> None: ...
	def Apply(self, form: IFSelect_EditForm, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...
	def Label(self) -> TCollection_AsciiString: ...
	def Load(self, form: IFSelect_EditForm, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...
	def Recognize(self, form: IFSelect_EditForm) -> bool: ...
	@staticmethod
	def StaticEditor(list: TColStd_HSequenceOfHAsciiString, label: Optional[str] = "") -> IFSelect_ParamEditor: ...
	def StringValue(self, form: IFSelect_EditForm, num: int) -> TCollection_HAsciiString: ...

class IFSelect_SelectBase(IFSelect_Selection):
	def FillIterator(self, iter: IFSelect_SelectionIterator) -> None: ...

class IFSelect_SelectCombine(IFSelect_Selection):
	def Add(self, sel: IFSelect_Selection, atnum: Optional[int] = 0) -> None: ...
	def FillIterator(self, iter: IFSelect_SelectionIterator) -> None: ...
	def Input(self, num: int) -> IFSelect_Selection: ...
	def InputRank(self, sel: IFSelect_Selection) -> int: ...
	def NbInputs(self) -> int: ...
	@overload
	def Remove(self, sel: IFSelect_Selection) -> bool: ...
	@overload
	def Remove(self, num: int) -> bool: ...

class IFSelect_SelectControl(IFSelect_Selection):
	def FillIterator(self, iter: IFSelect_SelectionIterator) -> None: ...
	def HasSecondInput(self) -> bool: ...
	def MainInput(self) -> IFSelect_Selection: ...
	def SecondInput(self) -> IFSelect_Selection: ...
	def SetMainInput(self, sel: IFSelect_Selection) -> None: ...
	def SetSecondInput(self, sel: IFSelect_Selection) -> None: ...

class IFSelect_SelectDeduct(IFSelect_Selection):
	def Alternate(self) -> IFSelect_SelectPointed: ...
	def FillIterator(self, iter: IFSelect_SelectionIterator) -> None: ...
	def HasAlternate(self) -> bool: ...
	def HasInput(self) -> bool: ...
	def Input(self) -> IFSelect_Selection: ...
	def InputResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def SetInput(self, sel: IFSelect_Selection) -> None: ...

class IFSelect_SessionPilot(IFSelect_Activator):
	def __init__(self, prompt: Optional[str] = "") -> None: ...
	def Arg(self, num: int) -> str: ...
	def Clear(self) -> None: ...
	def Command(self, num: int) -> TCollection_AsciiString: ...
	def CommandLine(self) -> TCollection_AsciiString: ...
	def CommandPart(self, numarg: Optional[int] = 0) -> str: ...
	def Do(self, number: int, session: IFSelect_SessionPilot) -> IFSelect_ReturnStatus: ...
	def Execute(self, command: TCollection_AsciiString) -> IFSelect_ReturnStatus: ...
	def ExecuteAlias(self, aliasname: TCollection_AsciiString) -> IFSelect_ReturnStatus: ...
	def ExecuteCounter(self, counter: IFSelect_SignCounter, numword: int, mode: Optional[IFSelect_PrintCount] = IFSelect_CountByItem) -> IFSelect_ReturnStatus: ...
	def Help(self, number: int) -> str: ...
	def Library(self) -> IFSelect_WorkLibrary: ...
	def NbCommands(self) -> int: ...
	def NbWords(self) -> int: ...
	def Number(self, val: str) -> int: ...
	def Perform(self) -> IFSelect_ReturnStatus: ...
	def ReadScript(self, file: Optional[str] = "") -> IFSelect_ReturnStatus: ...
	def RecordItem(self, item: Standard_Transient) -> IFSelect_ReturnStatus: ...
	def RecordMode(self) -> bool: ...
	def RecordedItem(self) -> Standard_Transient: ...
	def RemoveWord(self, num: int) -> bool: ...
	def Session(self) -> IFSelect_WorkSession: ...
	def SetCommandLine(self, command: TCollection_AsciiString) -> None: ...
	def SetLibrary(self, WL: IFSelect_WorkLibrary) -> None: ...
	def SetRecordMode(self, mode: bool) -> None: ...
	def SetSession(self, WS: IFSelect_WorkSession) -> None: ...
	def Word(self, num: int) -> TCollection_AsciiString: ...

class IFSelect_SignCategory(IFSelect_Signature):
	def __init__(self) -> None: ...
	def Value(self, ent: Standard_Transient, model: Interface_InterfaceModel) -> str: ...

class IFSelect_SignCounter(IFSelect_SignatureList):
	@overload
	def __init__(self, withmap: Optional[bool] = True, withlist: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, matcher: IFSelect_Signature, withmap: Optional[bool] = True, withlist: Optional[bool] = False) -> None: ...
	def AddEntity(self, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...
	def AddFromSelection(self, sel: IFSelect_Selection, G: Interface_Graph) -> None: ...
	def AddList(self, list: TColStd_HSequenceOfTransient, model: Interface_InterfaceModel) -> None: ...
	def AddModel(self, model: Interface_InterfaceModel) -> None: ...
	def AddSign(self, ent: Standard_Transient, model: Interface_InterfaceModel) -> None: ...
	def AddWithGraph(self, list: TColStd_HSequenceOfTransient, graph: Interface_Graph) -> None: ...
	def ComputeSelected(self, G: Interface_Graph, forced: Optional[bool] = False) -> bool: ...
	def ComputedSign(self, ent: Standard_Transient, G: Interface_Graph) -> str: ...
	def SelMode(self) -> int: ...
	def Selection(self) -> IFSelect_Selection: ...
	def SetMap(self, withmap: bool) -> None: ...
	def SetSelMode(self, selmode: int) -> None: ...
	def SetSelection(self, sel: IFSelect_Selection) -> None: ...
	def Sign(self, ent: Standard_Transient, model: Interface_InterfaceModel) -> TCollection_HAsciiString: ...
	def Signature(self) -> IFSelect_Signature: ...

class IFSelect_SignMultiple(IFSelect_Signature):
	def __init__(self, name: str) -> None: ...
	def Add(self, subsign: IFSelect_Signature, width: Optional[int] = 0, maxi: Optional[bool] = False) -> None: ...
	def Matches(self, ent: Standard_Transient, model: Interface_InterfaceModel, text: TCollection_AsciiString, exact: bool) -> bool: ...
	def Value(self, ent: Standard_Transient, model: Interface_InterfaceModel) -> str: ...

class IFSelect_SignType(IFSelect_Signature):
	def __init__(self, nopk: Optional[bool] = False) -> None: ...
	def Value(self, ent: Standard_Transient, model: Interface_InterfaceModel) -> str: ...

class IFSelect_SignValidity(IFSelect_Signature):
	def __init__(self) -> None: ...
	@staticmethod
	def CVal(ent: Standard_Transient, model: Interface_InterfaceModel) -> str: ...
	def Value(self, ent: Standard_Transient, model: Interface_InterfaceModel) -> str: ...

class IFSelect_TransformStandard(IFSelect_Transformer):
	def __init__(self) -> None: ...
	def AddModifier(self, modif: IFSelect_Modifier, atnum: Optional[int] = 0) -> bool: ...
	def ApplyModifiers(self, G: Interface_Graph, protocol: Interface_Protocol, TC: Interface_CopyTool, checks: Interface_CheckIterator, newmod: Interface_InterfaceModel) -> bool: ...
	def Copy(self, G: Interface_Graph, TC: Interface_CopyTool, newmod: Interface_InterfaceModel) -> None: ...
	def CopyOption(self) -> bool: ...
	def Label(self) -> TCollection_AsciiString: ...
	def Modifier(self, num: int) -> IFSelect_Modifier: ...
	def ModifierRank(self, modif: IFSelect_Modifier) -> int: ...
	def NbModifiers(self) -> int: ...
	def OnTheSpot(self, G: Interface_Graph, TC: Interface_CopyTool, newmod: Interface_InterfaceModel) -> None: ...
	def Perform(self, G: Interface_Graph, protocol: Interface_Protocol, checks: Interface_CheckIterator, newmod: Interface_InterfaceModel) -> bool: ...
	@overload
	def RemoveModifier(self, modif: IFSelect_Modifier) -> bool: ...
	@overload
	def RemoveModifier(self, num: int) -> bool: ...
	def Selection(self) -> IFSelect_Selection: ...
	def SetCopyOption(self, option: bool) -> None: ...
	def SetSelection(self, sel: IFSelect_Selection) -> None: ...
	def StandardCopy(self, G: Interface_Graph, TC: Interface_CopyTool, newmod: Interface_InterfaceModel) -> None: ...
	def Updated(self, entfrom: Standard_Transient, entto: Standard_Transient) -> bool: ...

class IFSelect_GraphCounter(IFSelect_SignCounter):
	def __init__(self, withmap: Optional[bool] = True, withlist: Optional[bool] = False) -> None: ...
	def AddWithGraph(self, list: TColStd_HSequenceOfTransient, graph: Interface_Graph) -> None: ...
	def Applied(self) -> IFSelect_SelectDeduct: ...
	def SetApplied(self, sel: IFSelect_SelectDeduct) -> None: ...

class IFSelect_ModifEditForm(IFSelect_Modifier):
	def __init__(self, editform: IFSelect_EditForm) -> None: ...
	def EditForm(self) -> IFSelect_EditForm: ...
	def Label(self) -> TCollection_AsciiString: ...
	def Perform(self, ctx: IFSelect_ContextModif, target: Interface_InterfaceModel, protocol: Interface_Protocol, TC: Interface_CopyTool) -> None: ...

class IFSelect_ModifReorder(IFSelect_Modifier):
	def __init__(self, rootlast: Optional[bool] = True) -> None: ...
	def Label(self) -> TCollection_AsciiString: ...
	def Perform(self, ctx: IFSelect_ContextModif, target: Interface_InterfaceModel, protocol: Interface_Protocol, TC: Interface_CopyTool) -> None: ...

class IFSelect_SelectAnyList(IFSelect_SelectDeduct):
	def FillResult(self, n1: int, n2: int, ent: Standard_Transient, res: Interface_EntityIterator) -> None: ...
	def HasLower(self) -> bool: ...
	def HasUpper(self) -> bool: ...
	def KeepInputEntity(self, iter: Interface_EntityIterator) -> None: ...
	def Label(self) -> TCollection_AsciiString: ...
	def ListLabel(self) -> TCollection_AsciiString: ...
	def Lower(self) -> IFSelect_IntParam: ...
	def LowerValue(self) -> int: ...
	def NbItems(self, ent: Standard_Transient) -> int: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def SetFrom(self, rankfrom: IFSelect_IntParam) -> None: ...
	def SetOne(self, rank: IFSelect_IntParam) -> None: ...
	def SetRange(self, rankfrom: IFSelect_IntParam, rankto: IFSelect_IntParam) -> None: ...
	def SetUntil(self, rankto: IFSelect_IntParam) -> None: ...
	def Upper(self) -> IFSelect_IntParam: ...
	def UpperValue(self) -> int: ...

class IFSelect_SelectDiff(IFSelect_SelectControl):
	def __init__(self) -> None: ...
	def Label(self) -> TCollection_AsciiString: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...

class IFSelect_SelectEntityNumber(IFSelect_SelectBase):
	def __init__(self) -> None: ...
	def Label(self) -> TCollection_AsciiString: ...
	def Number(self) -> IFSelect_IntParam: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def SetNumber(self, num: IFSelect_IntParam) -> None: ...

class IFSelect_SelectExplore(IFSelect_SelectDeduct):
	def Explore(self, level: int, ent: Standard_Transient, G: Interface_Graph, explored: Interface_EntityIterator) -> bool: ...
	def ExploreLabel(self) -> TCollection_AsciiString: ...
	def Label(self) -> TCollection_AsciiString: ...
	def Level(self) -> int: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...

class IFSelect_SelectExtract(IFSelect_SelectDeduct):
	def ExtractLabel(self) -> TCollection_AsciiString: ...
	def IsDirect(self) -> bool: ...
	def Label(self) -> TCollection_AsciiString: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def SetDirect(self, direct: bool) -> None: ...
	def Sort(self, rank: int, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...
	def SortInGraph(self, rank: int, ent: Standard_Transient, G: Interface_Graph) -> bool: ...

class IFSelect_SelectIntersection(IFSelect_SelectCombine):
	def __init__(self) -> None: ...
	def Label(self) -> TCollection_AsciiString: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...

class IFSelect_SelectModelEntities(IFSelect_SelectBase):
	def __init__(self) -> None: ...
	def CompleteResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def Label(self) -> TCollection_AsciiString: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...

class IFSelect_SelectModelRoots(IFSelect_SelectBase):
	def __init__(self) -> None: ...
	def Label(self) -> TCollection_AsciiString: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...

class IFSelect_SelectPointed(IFSelect_SelectBase):
	def __init__(self) -> None: ...
	def Add(self, item: Standard_Transient) -> bool: ...
	def AddList(self, list: TColStd_HSequenceOfTransient) -> bool: ...
	def Clear(self) -> None: ...
	def IsSet(self) -> bool: ...
	def Item(self, num: int) -> Standard_Transient: ...
	def Label(self) -> TCollection_AsciiString: ...
	def NbItems(self) -> int: ...
	def Rank(self, item: Standard_Transient) -> int: ...
	def Remove(self, item: Standard_Transient) -> bool: ...
	def RemoveList(self, list: TColStd_HSequenceOfTransient) -> bool: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def SetEntity(self, item: Standard_Transient) -> None: ...
	def SetList(self, list: TColStd_HSequenceOfTransient) -> None: ...
	def Toggle(self, item: Standard_Transient) -> bool: ...
	def ToggleList(self, list: TColStd_HSequenceOfTransient) -> bool: ...
	@overload
	def Update(self, control: Interface_CopyControl) -> None: ...
	@overload
	def Update(self, trf: IFSelect_Transformer) -> None: ...

class IFSelect_SelectShared(IFSelect_SelectDeduct):
	def __init__(self) -> None: ...
	def Label(self) -> TCollection_AsciiString: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...

class IFSelect_SelectSharing(IFSelect_SelectDeduct):
	def __init__(self) -> None: ...
	def Label(self) -> TCollection_AsciiString: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...

class IFSelect_SelectSuite(IFSelect_SelectDeduct):
	def __init__(self) -> None: ...
	def AddInput(self, item: IFSelect_Selection) -> bool: ...
	def AddNext(self, item: IFSelect_SelectDeduct) -> None: ...
	def AddPrevious(self, item: IFSelect_SelectDeduct) -> None: ...
	def Item(self, num: int) -> IFSelect_SelectDeduct: ...
	def Label(self) -> TCollection_AsciiString: ...
	def NbItems(self) -> int: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def SetLabel(self, lab: str) -> None: ...

class IFSelect_SelectUnion(IFSelect_SelectCombine):
	def __init__(self) -> None: ...
	def Label(self) -> TCollection_AsciiString: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...

class IFSelect_SignAncestor(IFSelect_SignType):
	def __init__(self, nopk: Optional[bool] = False) -> None: ...
	def Matches(self, ent: Standard_Transient, model: Interface_InterfaceModel, text: TCollection_AsciiString, exact: bool) -> bool: ...

class IFSelect_SelectAnyType(IFSelect_SelectExtract):
	def Sort(self, rank: int, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...
	def TypeForMatch(self) -> Standard_Type: ...

class IFSelect_SelectErrorEntities(IFSelect_SelectExtract):
	def __init__(self) -> None: ...
	def ExtractLabel(self) -> TCollection_AsciiString: ...
	def Sort(self, rank: int, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...

class IFSelect_SelectFlag(IFSelect_SelectExtract):
	def __init__(self, flagname: str) -> None: ...
	def ExtractLabel(self) -> TCollection_AsciiString: ...
	def FlagName(self) -> str: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def Sort(self, rank: int, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...

class IFSelect_SelectInList(IFSelect_SelectAnyList):
	def FillResult(self, n1: int, n2: int, ent: Standard_Transient, result: Interface_EntityIterator) -> None: ...
	def ListedEntity(self, num: int, ent: Standard_Transient) -> Standard_Transient: ...

class IFSelect_SelectRange(IFSelect_SelectExtract):
	def __init__(self) -> None: ...
	def ExtractLabel(self) -> TCollection_AsciiString: ...
	def HasLower(self) -> bool: ...
	def HasUpper(self) -> bool: ...
	def Lower(self) -> IFSelect_IntParam: ...
	def LowerValue(self) -> int: ...
	def SetFrom(self, rankfrom: IFSelect_IntParam) -> None: ...
	def SetOne(self, rank: IFSelect_IntParam) -> None: ...
	def SetRange(self, rankfrom: IFSelect_IntParam, rankto: IFSelect_IntParam) -> None: ...
	def SetUntil(self, rankto: IFSelect_IntParam) -> None: ...
	def Sort(self, rank: int, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...
	def Upper(self) -> IFSelect_IntParam: ...
	def UpperValue(self) -> int: ...

class IFSelect_SelectRootComps(IFSelect_SelectExtract):
	def __init__(self) -> None: ...
	def ExtractLabel(self) -> TCollection_AsciiString: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def Sort(self, rank: int, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...

class IFSelect_SelectRoots(IFSelect_SelectExtract):
	def __init__(self) -> None: ...
	def ExtractLabel(self) -> TCollection_AsciiString: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def Sort(self, rank: int, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...

class IFSelect_SelectSent(IFSelect_SelectExtract):
	def __init__(self, sentcount: Optional[int] = 1, atleast: Optional[bool] = True) -> None: ...
	def AtLeast(self) -> bool: ...
	def ExtractLabel(self) -> TCollection_AsciiString: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...
	def SentCount(self) -> int: ...
	def Sort(self, rank: int, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...

class IFSelect_SelectSignature(IFSelect_SelectExtract):
	@overload
	def __init__(self, matcher: IFSelect_Signature, signtext: str, exact: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, matcher: IFSelect_Signature, signtext: TCollection_AsciiString, exact: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, matcher: IFSelect_SignCounter, signtext: str, exact: Optional[bool] = True) -> None: ...
	def Counter(self) -> IFSelect_SignCounter: ...
	def ExtractLabel(self) -> TCollection_AsciiString: ...
	def IsExact(self) -> bool: ...
	def Signature(self) -> IFSelect_Signature: ...
	def SignatureText(self) -> TCollection_AsciiString: ...
	def Sort(self, rank: int, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...
	def SortInGraph(self, rank: int, ent: Standard_Transient, G: Interface_Graph) -> bool: ...

class IFSelect_SelectSignedShared(IFSelect_SelectExplore):
	def __init__(self, matcher: IFSelect_Signature, signtext: str, exact: Optional[bool] = True, level: Optional[int] = 0) -> None: ...
	def Explore(self, level: int, ent: Standard_Transient, G: Interface_Graph, explored: Interface_EntityIterator) -> bool: ...
	def ExploreLabel(self) -> TCollection_AsciiString: ...
	def IsExact(self) -> bool: ...
	def Signature(self) -> IFSelect_Signature: ...
	def SignatureText(self) -> TCollection_AsciiString: ...

class IFSelect_SelectSignedSharing(IFSelect_SelectExplore):
	def __init__(self, matcher: IFSelect_Signature, signtext: str, exact: Optional[bool] = True, level: Optional[int] = 0) -> None: ...
	def Explore(self, level: int, ent: Standard_Transient, G: Interface_Graph, explored: Interface_EntityIterator) -> bool: ...
	def ExploreLabel(self) -> TCollection_AsciiString: ...
	def IsExact(self) -> bool: ...
	def Signature(self) -> IFSelect_Signature: ...
	def SignatureText(self) -> TCollection_AsciiString: ...

class IFSelect_SelectUnknownEntities(IFSelect_SelectExtract):
	def __init__(self) -> None: ...
	def ExtractLabel(self) -> TCollection_AsciiString: ...
	def Sort(self, rank: int, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...

class IFSelect_SelectIncorrectEntities(IFSelect_SelectFlag):
	def __init__(self) -> None: ...

class IFSelect_SelectType(IFSelect_SelectAnyType):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, atype: Standard_Type) -> None: ...
	def ExtractLabel(self) -> TCollection_AsciiString: ...
	def SetType(self, atype: Standard_Type) -> None: ...
	def TypeForMatch(self) -> Standard_Type: ...

# harray1 classes
# harray2 classes
# hsequence classes

class IFSelect_HSeqOfSelection(IFSelect_TSeqOfSelection, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: IFSelect_TSeqOfSelection) -> None: ...
    def Sequence(self) -> IFSelect_TSeqOfSelection: ...
    def Append(self, theSequence: IFSelect_TSeqOfSelection) -> None: ...


ifselect_RestoreSession = ifselect.RestoreSession
ifselect_SaveSession = ifselect.SaveSession
IFSelect_Activator_Adding = IFSelect_Activator.Adding
IFSelect_Activator_Commands = IFSelect_Activator.Commands
IFSelect_Activator_Mode = IFSelect_Activator.Mode
IFSelect_Activator_Remove = IFSelect_Activator.Remove
IFSelect_Activator_Select = IFSelect_Activator.Select
IFSelect_Functions_GiveDispatch = IFSelect_Functions.GiveDispatch
IFSelect_Functions_GiveEntity = IFSelect_Functions.GiveEntity
IFSelect_Functions_GiveEntityNumber = IFSelect_Functions.GiveEntityNumber
IFSelect_Functions_GiveList = IFSelect_Functions.GiveList
IFSelect_Functions_Init = IFSelect_Functions.Init
IFSelect_SessionDumper_First = IFSelect_SessionDumper.First
IFSelect_Signature_IntValue = IFSelect_Signature.IntValue
IFSelect_Signature_MatchValue = IFSelect_Signature.MatchValue
IFSelect_Act_AddFSet = IFSelect_Act.AddFSet
IFSelect_Act_AddFunc = IFSelect_Act.AddFunc
IFSelect_Act_SetGroup = IFSelect_Act.SetGroup
IFSelect_ParamEditor_StaticEditor = IFSelect_ParamEditor.StaticEditor
IFSelect_SignValidity_CVal = IFSelect_SignValidity.CVal
